% Function calculates the interfacial tension between an oil and gas phase
% Baker, O. and Swerdloff corrolation (1955) recommended by Beggs
%   -  Ref: Oil Gas J. (5 December 1955): 141

% Input:
% API   -   API Gravity Oil
% p     -   Pressure, psi
% T     -   Temperature, F

% Output:
% sigma -   Interfacial Tension, dynes/cm^2

function sigma = IFT(API,p,T)

sigma68 = 39 - 0.2571*API;                          % Interfacial tension for temperatures below 86F
sigma100 = 37.5 - 0.2571*API;                       % Interfacial tension for temperatures above 100F
sigmaN = sigma68 - (T-68)*(sigma68-sigma100)/32;    % Linear appoximation between 86F and 100F

    if T > 100
        sigmaOD = sigma100;                         % Assigning of correct value
    elseif T < 68
        sigmaOD = sigma68;
    else
        sigmaOD = sigmaN;
    end

    x = exp(-8.6306*10^-4*p);                       % Convert from dead oil to live interacial tension
    sigma = sigmaOD*x;                              % Calculated interfacial tension, dynes/cm^2
end

