% Function calculates the interfacial tension between an water and gas phase
% http://www.fekete.com/SAN/WebHelp/virtuwell/webhelp/c-te-glossary.htm


% Input:
% p     -   Pressure, psi
% T     -   Temperature, F

% Output:
% sigma -   Interfacial Tension, dynes/cm^2

function sigma = IFTW(p,T)

sigma74 = 75 - 1.108*p^0.349;                          % Interfacial tension for temperatures below 74F
sigma280 = 53 - 0.1048*p^0.637;                       % Interfacial tension for temperatures above 280F
sigmaN = sigma74 - (T-74)*(sigma74-sigma280)/206;    % Linear appoximation between 74F and 280F

    if T > 280
        sigma = sigma280;                         % Assigning of correct value
    elseif T < 74
        sigma = sigma74;
    else
        sigma = sigmaN;
    end
    
end

