clc
clear all
close all

%% Constant Fluid Properties
WC = 0.20;
qL_SC = 5000;   %	Liquid production rate:	2000	  stb/d
GLR = 2000;       %	Producing gas-liquid ratio (GLR):	1000	  scf/stb
GASTYPE = 'CH4';                                    % Gas in system
[Mg, yG] = gasprop(GASTYPE);
yW = 1.05;
API = 20;                                           % API Gravity Oil
yO = 141.5/(API+131.5);                             % Specific Gravity Oil

%% Data
P_Choke = 100;                                      % Back Pressure, psia
limit = 0.01;                                       % Iteration limit, psia
Nozzle = [16 16 16];                                % Bit Jet Sizes, in/32
Cd = 0.98;                                          % Discharge Coefficient

TempTable = get(handles.temptable, 'Data');
Geometry = get(handles.schematictot,'Data');
Welldata = get(handles.uitable8, 'Data');

%% Section Places Well Data Into Vectors
intervals   = size(Welldata, 1)-1;                    % Number of intervals in data
ds_Interval = transpose(1:intervals);               % Numbers interval
ds_MDoutA   = double(Welldata(2:intervals+1,2));      % Measured depth annular outflow, ft
ds_MDinA    = double(Welldata(1:intervals,2));         % Measured depth annular inflow, ft
ds_TVDoutA  = double(Welldata(2:intervals+1,5));     % TVD annular outflow, ft 
ds_TVDinA   = double(Welldata(1:intervals,5));        % TVD annular inflow, ft 
ds_MDoutD   = double(Welldata(1:intervals,2));        % Measured depth drill string outflow, ft
ds_MDinD    = double(Welldata(2:intervals+1,2));       % Measured depth drill string inflow, ft
ds_TVDoutD  = double(Welldata(1:intervals,5));       % TVD drill string outflow, ft 
ds_TVDinD   = double(Welldata(2:intervals+1,5));      % TVD drill string inflow, ft 
ds_MDavg = (ds_MDinA + ds_MDoutA)/2;                % Average measured depth, ft
ds_Vsecin = double(Welldata(1:intervals,11));       % Vertical Section Top, ft
ds_Vsecout = double(Welldata(2:intervals+1,11));    % Vertical Section Bottom, ft
Vsec = (ds_Vsecin+ds_Vsecout)/2;                    % Average Vertical Section, ft

for i = 1:intervals      
    MD = ds_MDoutA(i);
    found = 0;
    index = 1;
    while found == 0;
        if Geometry(index,1)<(MD-0.001);
            index = index + 1;
        else
            found = 1;
        end
    end
    d1 = Geometry(index,2)/12;
    d2 = Geometry(index,3)/12;
    d3 = Geometry(index,4)/12;
    ds_diDS(i) = d1;
    ds_doDS(i) = d2;
    ds_dHS(i) = d3;
end


ds_dp_guessA = zeros(intervals,1);                  % First annular pressure change guessed, psi
ds_dZ = abs(ds_MDoutA - ds_MDinA);                  % Length of interval, ft
ds_dhA = ds_TVDoutA - ds_TVDinA;                    % Depth change interval, ft
ds_phiA = asind(ds_dhA./ds_dZ);                     % Calculted Inclination, degrees
ds_TVDavg = (ds_TVDinA + ds_TVDoutA)/2;             % Average TVD, ft
TT = interp1(TempTable(:,1),TempTable(:,3),ds_TVDavg);
ds_TavgF = TT; %Tsurf + ds_TVDavg.*TempGrad;             % Average temperature, F
ds_iterA = zeros(intervals, 1);                     % Iteration Counter
ds_ADS = pi/4*ds_diDS.^2;                           % Flow Area Drill String, sqft
ds_Aann = pi/4*(ds_dHS.^2-ds_doDS.^2);              % Flow Area Annulus, sqft
ds_dPA = zeros(intervals, 1);                       % Pressure Change, psi
ds_poutA = zeros(intervals, 1);                     % Define Outflow Pressure Annulus, psi
ds_pinA = zeros(intervals, 1);                      % Define Inflow Pressure Annulus, psi
ds_pavgA = zeros(intervals, 1);                     % Calculated pressure defined, psi
ds_dPdZA = zeros(intervals, 1);                     % Annular Pressure Gradient Defined, psi/ft
ds_dp_guessD = zeros(intervals,1);                  % First string pressure change guessed, psi
ds_dhD = ds_TVDoutD - ds_TVDinD;                    % Depth change interval, ft
ds_phiD = asind(ds_dhD./ds_dZ);                     % Calculted Inclination, degrees
ds_iterD = zeros(intervals, 1);                     % Iteration Counter
ds_dPD = zeros(intervals, 1);                       % Pressure Change, psi

%%% UNCOMMENT TO RUN MULTIPLE SIMULATIONS 
% tellerQ = 0;                                      % Initiate Counter Flowrates
% for qO1 = 40/42*60*24:20/42*60*24:260/42*60*24    % Oil Flow Rates to test, stb/D
% %for qG1 = 60*24*200:60*24*200:60*24*3000         % Gas Flow Rates to test, scf/D
%     tellerQ = tellerQ + 1;                        % Increase Flow Iteration
%     tellerC = 0;                                  % Initiate Counter Choke
% for P_Choke = (3:16).^3                           % Choke Pressures to test, psi
%    tellerC = tellerC + 1;                         % Increase Choke Iteration


%% Section Simulates Fluid Flow Up Annulus
% Simulated against flow direction  - Positive pressure gradient

for ii = 1:intervals                                                        % Loop over all intervals

    deviation = 1000;                                                       % Define Pressure deviation, psi
    ds_iterA(ii) = 0;                                                       % Initiate Interval Iteration Counter
    
    while(abs(deviation)>limit)                                             % Checks if iteration limit is reached

        ds_iterA(ii) = ds_iterA(ii) + 1;                                    % Iteration Counter Increases
        
        % Section Estimates the Average Pressure
        if (ii>1)
            ds_pinA(ii) = ds_poutA(ii-1);                                   % Inlet Pressure Equals Outles Pressure Last Interval
        else
            ds_pinA(ii) = P_Choke;                                          % Inlet Pressure Equals Choke Pressure at Surface
        end
        ds_poutA(ii) = ds_pinA(ii) + ds_dp_guessA(ii);                      % Calculates Outlet Pressure from Inlet and Guessed Change, psi
        ds_pavgA(ii) = (ds_pinA(ii) + ds_poutA(ii))/2;                      % Average Pressure, psi      
        
        do = ds_dHS(ii);
        inc = ds_phiA(ii);
        di = ds_doDS(ii);
        T = ds_TavgF(ii);
        P = ds_pavgA(ii);
        ds_dPdZA(ii) = cor_input(do, inc, di, qL_SC, GLR, WC, API, yW, yG, T, P);

        ds_dPA(ii) = ds_dPdZA(ii).*ds_dZ(ii);                               % Calculated Pressure Change Over Interval, psi
        deviation = ds_dp_guessA(ii)-ds_dPA(ii);                            % Pressure Deviation From Guess, psi 
        ds_dp_guessA(ii) = ds_dPA(ii);                                      % New Guess Pressure Change (next iteration), psi
        
        % Section Tries Average Value of Two Iterations if Convergence Fails
        if (ds_iterA(ii) == 201)
            dev1 = deviation;                                               % Holds Calculated Deviation
            val1 = ds_dp_guessA(ii);                                        % Holds Calculated Pressure
        elseif (ds_iterA(ii) == 202)
            dev2 = deviation;                                               % Holds Calculated Deviation, psi
            val2 = ds_dp_guessA(ii);                                        % Holds Calculated Pressure, psi
            ds_dp_guessA(ii) = mean([val1 val2]);                           % Average Pressure of Two Last Iterations, psi
            deviation = mean([dev1 dev2]);                                  % Average Deviation of Two Last Iterations, psi
        end
        
    end
    
    ds_poutA(ii) = ds_pinA(ii) + ds_dPA(ii);                                % Outlet Pressure of Interval, psi
    
end

BHP = ds_poutA(intervals);                                                  % Estimated BHP (Outlet Pressure Last Interval), psi


%% Bit Pressure Drop
% Section Calculate Fluid Properties At Bit
[qT, rhoM] = helpfunction_bit(GASTYPE, qL_SC,...
    GLR, WC, API, yW, yG, TT(intervals), BHP);
q_bit = qT*60*12^3/231;                                                     % Converts Flow from cuft/sec to gpm
rho_bit = rhoM/(12^3/231);                                                  % Converts Mixture Density from lbm/cuft to ppg
dbit = pnozzle(q_bit,rho_bit,Cd,Nozzle(1),Nozzle(2),Nozzle(3));             % Pressure Drop Over Bit, psi
ds_pinD(intervals) = BHP + dbit;                                            % Pressure Behind Bit (inside string), psi


%% Section Simulates Fluid Flow Down Drill String
% Simulated against flow direction  - Positive pressure gradient
for ii = intervals:-1:1                                                     % Loop over all intervals

    deviation = 1000;                                                       % Define Pressure deviation, psi
    ds_iterD(ii) = 0;
    
    while(abs(deviation)>limit)                                             % Checks if iteration limit is reached

        ds_iterD(ii) = ds_iterD(ii) + 1;                                    % Iteration Counter Increases

        % Section Estimates the Average Pressure
        if (ii ~= intervals)
            ds_pinD(ii) = ds_poutD(ii+1);                                   % Inlet Pressure Equals Outles Pressure Last Interval
        else
            ds_pinD(ii) = BHP + dbit;                                       % Inlet Pressure Equals Choke Pressure at Surface
        end      
        ds_poutD(ii) = ds_pinD(ii) + ds_dp_guessD(ii);                      % Calculates Outlet Pressure from Inlet and Guessed Change, psi
        ds_pavgD(ii) = (ds_pinD(ii) + ds_poutD(ii))/2;                      % Average Pressure, psi
        
        do = ds_diDS(ii);
        inc = ds_phiD(ii);
        di = 0;
        T = ds_TavgF(ii);
        P = ds_pavgD(ii);
        ds_dPdZD(ii) = cor_input(do, inc, di, qL_SC, GLR, WC, API, yW, yG, T, P);

        ds_dPD(ii) = ds_dPdZD(ii).*ds_dZ(ii);                               % Calculated Pressure Change Over Interval, psi
        deviation = ds_dp_guessD(ii)-ds_dPD(ii);                            % Pressure Deviation From Guess, psi
        ds_dp_guessD(ii) = ds_dPD(ii);                                      % New Guess Pressure Change (next iteration), psi
          
        % Section Tries Average Value of Two Iterations if Convergence Fails
        if (ds_iterD(ii) == 201)
            dev1 = deviation;                                               % Holds Calculated Deviation
            val1 = ds_dp_guessD(ii);                                        % Holds Calculated Pressure
        elseif (ds_iterD(ii) == 202)
            dev2 = deviation;                                               % Holds Calculated Deviation, psi
            val2 = ds_dp_guessD(ii);                                        % Holds Calculated Pressure, psi
            ds_dp_guessD(ii) = mean([val1 val2]);                           % Average Pressure of Two Last Iterations, psi
            deviation = mean([dev1 dev2]);                                  % Average Deviation of Two Last Iterations, psi
        end
        
    end
    
    ds_poutD(ii) = ds_pinD(ii) + ds_dPD(ii);                                % Outlet Pressure of Interval, psi
    
end
PDS = ds_poutD(1);                                                          % Estimated Drill Pipe Pressure (Outlet Pressure Last Interval), psi

% %UNCOMMENT ALSO THIS SECTION FOR MULTIPLE SIMULATIONS
% DATA(tellerC,1,tellerQ) = P_Choke;
% DATA(tellerC,2,tellerQ) = BHP;
% DATA(tellerC,3,tellerQ) = PDS;
% DATA(tellerC,4,tellerQ) = qG1;
% [tellerQ tellerC]
% end
%     end



%% This Section Plots the Results

% UNCOMMENT FOR ADVANCED PLOT
subplot(141)
plot(ds_dHS*12, ds_MDavg, ds_doDS*12, ds_MDavg, ds_diDS*12, ds_MDavg)
set(gca,'YDir','reverse')
title('Diameter Deviated Well')
xlabel('Diameter, in')
ylabel('Measured Depth, ft')
legend('ID Casing','OD Drill Pipe', 'ID Drill Pipe')
grid on
subplot(142)
plot(ds_dPdZA, ds_MDavg, 'r', ds_dPdZD, ds_MDavg, 'b')
set(gca,'YDir','reverse')
title('Pressure Gradient Deviated Well')
xlabel('Pressure, psi/ft')
ylabel('Measured Depth, ft')
legend('Annulus', 'Drill String')
grid on
subplot(143)
plot(ds_pavgA, ds_MDavg, 'r', ds_pavgD, ds_MDavg, 'b')
set(gca,'YDir','reverse')
title('Pressure Profile Deviated Well')
xlabel('Pressure, psi')
ylabel('Measured Depth, ft')
legend('Annulus', 'Drill String')
grid on
subplot(144)
plot(Vsec, ds_TVDavg, 'r')
set(gca,'YDir','reverse')
title('Well Trajectory')
xlabel('Vertical Section, ft')
ylabel('True Vertical Depth, ft')
xmin = min(Vsec)-100;
xmax = max(Vsec)+100;
xlim([xmin xmax])
legend('Well')
grid on
% 
% % UNCOMMENT FOR SIMPLE PLOTTING
% plot(ds_pavgA, ds_TVDavg, 'r', ds_pavgD, ds_TVDavg, 'b')
% set(gca,'YDir','reverse')
% title('Pressure Profile Simple Vertical Well')
% xlabel('Pressure, psi')
% ylabel('True Vertical Depth, ft')
% legend('Annulus', 'Drill String')
% grid on


% % UNCOMMENT FOR PLOTTING WHEN MULTIPLE SIMULATIONS ARE RUN 
% for f = 1:14
% hold all
% plot(DATA(2:14,1,f), DATA(2:14,2,f), 'DisplayName',[num2str(DATA(1,4,f)/60/24) ' scfpm'], 'Color',[f/14 0 1-f/14]);
% end
% 
% grid on
% ylabel('Bottomhole Pressure, psi')
% xlabel('Choke Pressure, psi')
% title('Bottom hole pressure for different gas flow rates')
% % 
% % for f = 3:12
% % plot(DATA(:,1,f), DATA(:,2,f), 'DisplayName',[num2str(DATA(1,4,f)/60/24*42) ' stbpm'], 'Color',[f/12 0 1-f/12])
% % hold all
% end
% grid on
% ylabel('Bottomhole Pressure, psi')
% xlabel('Choke Pressure, psi')
% title('Bottom hole pressure for different liquid flow rates')
