% Function to Calculate Pressure Drop Over Choke
% Using Gilbert's Choke Equation

% Input:
% GLR   -   Gas Liquid Ratio, Scf/STB
% qL    -   Oil Production Rate, STB/D
% d     -   Choke Opening, 1/64 inch

% Output:
% pwf   -   Pressure Drop, psi

function pwf = choke(qL, GLR, d)

A1 = 3.86*10^-3;            % Constant
A2 = 0.546;                 % Constant
A3 = 1.89;                  % Constant
f = d/64;                   % Choke Opening, in
pwf = A1*qL*GLR^A2/f^A3;    % Flowing Wellhead Pressure, psi

end

