% Function to Calculate Choke Opening
% Using Gilbert's Choke Equation (inverse)

% Input:
% GLR   -   Gas Liquid Ratio, Scf/STB
% qL    -   Oil Production Rate, STB/D
% pwf   -   Pressure Drop, psi

% Output:
% d     -   Choke Opening, 1/64 inch

function d = choke_inv(qL, GLR, pwf)

A1 = 3.86*10^-3;                        % Constant
A2 = 0.546;                             % Constant
A3 = 1.89;                              % Constant
f = (pwf*GLR^(-A2)/(A1*qL))^(-1/A3);    % Choke Opening, in
d = f*64;                               % Choke Opening, 1/64 in

end

