%clear all; close all; clc;
hold all
%% Inputs
GASTYPE = 'CH4';
%corrolation = 'Hagedorn';
corrolation = 'Poettmann';
%corrolation = 'PoettmannSIMPLIFIED';
%corrolation = 'Baxendell';
%corrolation = 'Brown';
%corrolation = 'BeggsBrill';
%corrolation = 'Ny';

do = 2.441/12;         %	Tubing ID:	1.66	  in
di = 0/12;
dh = do - di;
P = 500;        %	Wellhead pressure:	500	  psia
qL_SC = 2000;   %	Liquid production rate:	2000	  stb/d
GLR = 1000;       %	Producing gas-liquid ratio (GLR):	1000	  scf/stb
WC = 0.10;      %	Water cut (WC):	25	  %
API = 30;       %	Oil gravity:	30	  oAPI
yW = 1.05;      %	Water specific gravity:	1.05	  1 for fresh water
yG = 0.65;      %	Gas specific gravity:	0.65	  1 for air
T = 150;        %	Wellhead temperature:	100	  oF

vector = [];
for P = 50:10:5000
%% Constants
rhoAIR = 0.0765;
g = 32.2;

%% Init Calc
Mg = 28.97*yG;
Area = pi/4*(do^2-di^2);
yO = 141.5/(API+131.5);

qG_SC = qL_SC*GLR; %scf/day
qW_SC = qL_SC*WC; % bbl/day
qO_SC = qL_SC*(1-WC); %bbl/day
WOR = qW_SC/qO_SC;%bbl/stb
GOR = qG_SC/qO_SC; %scf/stb

Bw = bw_mccain(P,T);
pb = p_bubble(GOR,yG,T,API);                                         % Bubble Point Pressure, psi
[Rs, Bo] = standing(yG, API, pb, P, T);
z = zfac4(GASTYPE,T,P);                                             % Gas Compressibility
Bg = (14.7/P)*((T+459.67)/519.67)*z;            % cuft/scf
qG = qO_SC*(GOR-Rs)*Bg/(3600*24);               % cuft/sec
qO = 6.49*10^-5*qO_SC*Bo;                       % cuft/sec
qW = 6.49*10^-5*qW_SC*Bw;                       % cuft/sec
qL = qO + qW;                                   % cuft/sec
qT = qL + qG;                                   % cuft/sec
rhoG = 2.7*P*yG/(z*(T+459.67)); %1.79;                 % lbm/cuft
rhoO = (yO*62.4+yG*0.0764*Rs/5.614)/Bo;         % lbm/cuft
rhoW = yW*62.4/Bw;                              % lbm/cuft
VolumeO = Bo*5.615;                             % cuft/stb
VolumeW = Bw*5.615*WOR;                         % cuft/stb
VolumeL = VolumeO + VolumeW;                    % cuft/stb
VolumeG = Bg*(GOR-Rs);                          % cuft/stb
VolumeT = VolumeL + VolumeG;                    % cuft/stb
MassW = 350.17*yO;                              % lbm/stb
MassO = 350.17*yW*WOR;                          % lbm/stb
MassL = MassW + MassO;                          % lbm/stb
MassG = GOR*rhoAIR*yG;                          % lbm/stb
MassT = MassL + MassG;                          % lbm/stb
%rhon = MassT/VolumeM;                          % lbm/cuft

fO = qO/(qO+qW);                                % -
fW = 1 - fO;                                    % -
rhoL = rhoO*fO + rhoW*fW;  %49.9;                        % lbm/cuft
lamdaL = qL/(qL+qG);                            % -
lamdaG = 1 - lamdaL;                            % -
rhon = rhoL*lamdaL+rhoG*lamdaG;  %15.8;                % lbm/cuft
vsg = qG/Area; %1.93                                  % ft/sec
vsl = qL/Area; % 0.79; %                                 % ft/sec
vm = vsg + vsl;                                 % ft/sec

visO = oilviscosity(API,T,Rs,P,pb);             % cp
visW = waterviscosity(T);                       % cp
visG = gasviscosity(rhoG, Mg, T);               % cp
visL = visO*fO+visW*fW;                         % cp
visn = visL*lamdaL+visG*lamdaG;                 % cp
sigmaO = IFT(API,P,T);                          % dynes/cm2
sigmaW = IFT(10,P,T);                           % dynes/cm2, ASSUMED CORRECT AT API=10, MAKE CORROLATION
sigmaL = sigmaO*fO+sigmaW*fW;                   % dynes/cm2


VALUE = rhon*vm*dh;

switch corrolation
   case 'PoettmannSIMPLIFIED'
        M = MassT;               
        D_rho_v = 1.4737*10^-5*M*qO_SC/(dh);                % /ft
        f = 4*10^(1.444-2.5*log10(VALUE));
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;
        dPdZ_f = k/rhon;
        dPdZ_el = rhon;
        dPdZ = (dPdZ_f + dPdZ_el)/144;    %psi/ft
    case 'Poettmann'
        M = MassT;
        D_rho_v = 1.4737*10^-5*M*qO_SC/(dh);                % /ft
        load Poettmann.txt
        x_poettmann = Poettmann(:,1);
        y_poettmann = Poettmann(:,2);
        f = interp1(x_poettmann,y_poettmann,VALUE);   
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;
        dPdZ_f = k/rhon;
        dPdZ_el = rhon;
        dPdZ = (dPdZ_f + dPdZ_el)/144;    %psi/ft
    case 'Baxendell'
        M = MassT;
        D_rho_v = 1.4737*10^-5*M*qO_SC/(dh);                % /ft
        load Baxendell.txt
        x_baxendell = Baxendell(:,1);
        y_baxendell = Baxendell(:,2);
        f = interp1(x_baxendell,y_baxendell,VALUE);   
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;
        dPdZ_f = k/rhon;
        dPdZ_el = rhon;
        dPdZ = (dPdZ_f + dPdZ_el)/144;    %psi/ft       
    case 'Brown'
        M = MassT;
        D_rho_v = 1.4737*10^-5*M*qO_SC/(dh);                % /ft
        if GLR < 1500
            load BrownGLRb1500
            x_brown = BrownGLRb1500(:,1);
            y_brown = BrownGLRb1500(:,2);
        elseif GLR > 3000
            load BrownGLRa3000    
            x_brown = BrownGLRa3000(:,1);
            y_brown = BrownGLRa3000(:,2);
        else
            load BrownGLR1500t3000
            x_brown = BrownGLR1500t3000(:,1);
            y_brown = BrownGLR1500t3000(:,2);
        end
        f = interp1(x_brown,y_brown,VALUE);   
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;
        dPdZ_f = k/rhon;
        dPdZ_el = rhon;
        dPdZ = (dPdZ_f + dPdZ_el)/144;    %psi/ft              
    case 'Hagedorn'
        e = 0.0006*dh;      % SHOULD BE INPUT
        V = num2cell(hagedorn_brown_parameters(rhoL, sigmaL, vsl, vsg, dh, visL, P));
        [NLV, NGV, Nd, NL, CNL, HL_phi, phi, HL] = V{:};
        HG = 1 - HL;                                    % -
        vg = vsg/HG;                                    % ft/sec
        vl = vsl/HL;                                    % ft/sec
        vs = vg - vl;                                   % ft/sec
        viss = visL^HL*visG^HG;                         % cp
        rhok = rhoL*lamdaL^2/HL + rhoG*lamdaG^2/HG;     % lbm/cuft
        rhos = rhoL*HL + rhoG*HG;                       % lbm/cuft
        NRe = 1488*rhon*vm*dh/viss;
        f = (1/(-1.8*log10(((e/dh)/3.7)^1.11+(6.9/NRe))))^2; % Haaland
        dPdZ_el = rhos;
        dPdZ_f = f*rhon^2*vm^2/(2*g*dh*rhos); %lbf/cuft
        dPdZ = (dPdZ_el + dPdZ_f)/144; %psi/ft
    case 'BeggsBrill'
        phi = 90;
        NLV = 1.938*vsl*(rhoL/sigmaL)^(1/4);
        dPdZ = beggs_brill(vsg, vsl, rhoG, rhoL, visL, visG, NLV, P, phi, dh);
    otherwise
        dPdZ = 0;
end

vector = [vector dPdZ_f/144];
end
plot(vector)



















% 
% dev = 100;
% 
% 
% while dev > 0.001
%    
% 
% Pt_guess = Ptop;
% dP_guess = 0;
% 
% L = 1000;
% inter = 10;
% di = L/inter;
% 
% Pin = zeros(1, inter);
% Pout = zeros(1, inter);
% 
% iter = 1;
% depthI = 0:di:L;
% 
% for depth = depthI
%     
%     test = 1000;
%     
%     while test > 0.001
%     
%     if iter == 1
%         Pin(iter) = Pt_guess;
%     else
%         Pin(iter) = Pout(iter-1);
%     end
%     
%     Pout(iter) = Pin(iter) + dP_guess;
%     P = (Pin(iter)+Pout(iter))/2;
%     
%     rho=rho0*exp(c*(P-P0));  % lbm/cuft
%     m = Q*rho;               % lbm/sec
%     v = Q/A;                    % ft/sec
%     Re = 1488*rho*v*d/vis;   
%     f = 64/Re;
%     phi = 90;
%     dPdZ_el = rho*sind(phi)/144;                % Hydrostatic pressure drop, psi
%     dPdZ_f = f*rho*v^2/(2*g*d)/144;             % Frictional pressure drop, psi
%     dPdZ = (dPdZ_el + dPdZ_f);             % Total pressure drop, psi/ft
%     
%     %Pout(iter) = Pin(iter) + dPdZ;
%     
%     dPint = dPdZ*di;
%     
%     deviationInterval = abs(dPint-dP_guess);
%     dP_guess = dPint;
%     test = deviationInterval;
%     
%     
%     end
%     
%     
%     iter = iter + 1;
%     
%     
%     
% end
% 
% dev = Pbtm - Pout(inter+1)
% Ptop = Ptop + 0.8*dev;
% 
% end 