%clear all; close all; clc;
hold all
%% Inputs
GASTYPE = 'CH4';
corrolation = 'Hagedorn';
%corrolation = 'Poettmann';
%corrolation = 'PoettmannSIMPLIFIED';
%corrolation = 'Baxendell';
%corrolation = 'Brown';
%corrolation = 'BeggsBrill';
%corrolation = 'Ny';

do = 2.441/12;         %	Tubing ID:	1.66	  in 
inc = 60;

di = 0/12;
dh = do - di;
e = 0.0006*dh;      % SHOULD BE INPUT
P = 500;        %	Wellhead pressure:	500	  psia
qL_SC = 2000;   %	Liquid production rate:	2000	  stb/d
GLR = 1000;       %	Producing gas-liquid ratio (GLR):	1000	  scf/stb
WC = 0.10;      %	Water cut (WC):	25	  %
API = 30;       %	Oil gravity:	30	  oAPI
yW = 1.05;      %	Water specific gravity:	1.05	  1 for fresh water
yG = 0.65;      %	Gas specific gravity:	0.65	  1 for air
T = 150;        %	Wellhead temperature:	100	  oF

vector = [];
for P = 50:100:5000
%% Constants
rhoAIR = 0.0765;
g = 32.2;

%% Init Calc
Mg = 28.97*yG;
Area = pi/4*(do^2-di^2);
yO = 141.5/(API+131.5);

qG_SC = qL_SC*GLR; %scf/day
qW_SC = qL_SC*WC; % bbl/day
qO_SC = qL_SC*(1-WC); %bbl/day
WOR = qW_SC/qO_SC;%bbl/stb
GOR = qG_SC/qO_SC; %scf/stb

Bw = bw_mccain(P,T);
pb = p_bubble(GOR,yG,T,API);                                         % Bubble Point Pressure, psi
[Rs, Bo] = standing(yG, API, pb, P, T);
z = zfac4(GASTYPE,T,P);                                             % Gas Compressibility
Bg = (14.7/P)*((T+459.67)/519.67)*z;            % cuft/scf
qG = qO_SC*(GOR-Rs)*Bg/(3600*24);               % cuft/sec
qO = 6.49*10^-5*qO_SC*Bo;                       % cuft/sec
qW = 6.49*10^-5*qW_SC*Bw;                       % cuft/sec
qL = qO + qW;                                   % cuft/sec
qT = qL + qG;                                   % cuft/sec
rhoG = 2.7*P*yG/(z*(T+459.67)); %1.79;                 % lbm/cuft
rhoO = (yO*62.4+yG*0.0764*Rs/5.614)/Bo;         % lbm/cuft
rhoW = yW*62.4/Bw;                              % lbm/cuft
VolumeO = Bo*5.615;                             % cuft/stb
VolumeW = Bw*5.615*WOR;                         % cuft/stb
VolumeL = VolumeO + VolumeW;                    % cuft/stb
VolumeG = Bg*(GOR-Rs);                          % cuft/stb
VolumeT = VolumeL + VolumeG;                    % cuft/stb
MassW = 350.17*yO;                              % lbm/stb
MassO = 350.17*yW*WOR;                          % lbm/stb
MassL = MassW + MassO;                          % lbm/stb
MassG = GOR*rhoAIR*yG;                          % lbm/stb
MassT = MassL + MassG;                          % lbm/stb
%rhon = MassT/VolumeM;                          % lbm/cuft

fO = qO/(qO+qW);                                % -
fW = 1 - fO;                                    % -
rhoL = rhoO*fO + rhoW*fW;  %49.9;                        % lbm/cuft
lamdaL = qL/(qL+qG);                            % -
lamdaG = 1 - lamdaL;                            % -
rhon = rhoL*lamdaL+rhoG*lamdaG;  %15.8;         % Density, no-slip, lbm/cuft         % lbm/cuft
vsg = qG/Area; %1.93                                  % ft/sec
vsl = qL/Area; % 0.79; %                                 % ft/sec
vm = vsg + vsl;                                 % ft/sec

visO = oilviscosity(API,T,Rs,P,pb);             % cp
visW = waterviscosity(T);                       % cp
visG = gasviscosity(rhoG, Mg, T);               % cp
visL = visO*fO+visW*fW;                         % cp
visn = visL*lamdaL+visG*lamdaG;                 % cp
sigmaO = IFT(API,P,T);                          % dynes/cm2
sigmaW = IFT(10,P,T);                           % dynes/cm2, ASSUMED CORRECT AT API=10, MAKE CORROLATION
sigmaL = sigmaO*fO+sigmaW*fW;                   % dynes/cm2

NLV = 1.938*vsl*(rhoL/sigmaL)^(1/4);
VALUE = rhon*vm*dh;
M = MassT;
D_rho_v = 1.4737*10^-5*M*qO_SC/(dh);                % /ft 

switch corrolation
    case 'Hagedorn'
        V = num2cell(hagedorn_brown_parameters(rhoL, sigmaL, vsl, vsg, dh, visL, P));
        [NLV, NGV, Nd, NL, CNL, HL_phi, phi, HL] = V{:};
    case 'BeggsBrill'
        NFR = vm^2/(g*dh);                               % Froude Number 
        HL = beggs_brill_cor(NFR, lamdaL, NLV, inc);
    otherwise
        HL = lamdaL;
end

HG = 1 - HL;                                    % -
vg = vsg/HG;                                    % ft/sec
vl = vsl/HL;                                    % ft/sec
vs = vg - vl;                                   % ft/sec
viss = visL^HL*visG^HG;                         % cp
rhok = rhoL*lamdaL^2/HL + rhoG*lamdaG^2/HG;     % lbm/cuft
rhos = rhoL*HL + rhoG*HG;                       % Density, slip, lbm/cuft
NRes = 1488*rhon*vm*dh/viss;                    % ER DETTE RIKTIG REYNOLDS TIL HAGEDORN?
NRen = 1488*rhon*vm*dh/visn;                     % Reynolds number, no-slip


switch corrolation
    case 'Hagedorn'
        f = (1/(-1.8*log10(((e/dh)/3.7)^1.11+(6.9/NRes))))^2; % Haaland
        dPdZ_f = f*rhon^2*vm^2/(2*g*dh*rhos); %lbf/cuft
    case 'PoettmannSIMPLIFIED'
        f = 4*10^(1.444-2.5*log10(VALUE));
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;        
        dPdZ_f = k/rhon;
    case 'Poettmann'
        load Poettmann.txt
        x_poettmann = Poettmann(:,1);
        y_poettmann = Poettmann(:,2);
        f = interp1(x_poettmann,y_poettmann,VALUE);
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;        
        dPdZ_f = k/rhon;
    case 'Baxendell'
        load Baxendell.txt
        x_baxendell = Baxendell(:,1);
        y_baxendell = Baxendell(:,2);
        f = interp1(x_baxendell,y_baxendell,VALUE);
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;        
        dPdZ_f = k/rhon;
    case 'Brown'
        if GLR < 1500
            load BrownGLRb1500
            x_brown = BrownGLRb1500(:,1);
            y_brown = BrownGLRb1500(:,2);
        elseif GLR > 3000
            load BrownGLRa3000    
            x_brown = BrownGLRa3000(:,1);
            y_brown = BrownGLRa3000(:,2);
        else
            load BrownGLR1500t3000
            x_brown = BrownGLR1500t3000(:,1);
            y_brown = BrownGLR1500t3000(:,2);
        end
        f = interp1(x_brown,y_brown,VALUE);
        k = f*qO_SC^2*M^2/7.4137/10000000000/(dh)^5;        
        dPdZ_f = k/rhon;
    case 'BeggsBrill'
        fn = 1/(2*log10(NRen/(4.5223*log10(NRen)-3.8215)))^2;   % Friction factor, no-slip
        y = lamdaL/HL^2;                                       % Adjustment parameter
        y1 = log(y);                                            % Adjustment parameter
        if ((1<y) && (y<1.2))
            S = log(2.2*y-1.2);                                 % Slip correction parameter
        else
            S = y1/(-0.0523+3.182*y1-0.8725*y1^2+0.01853*y1^4); % Slip correction parameter
        end
        es = exp(S);                                            % Slip correction
        ftp = es*fn;                                            % Friction factor, two-phase flow
        dPdZ_f = ftp*rhon*vm^2/(2*g*dh);                         % Frictional pressure drop, psi
end


Ek = 0; %rhos*vm*vsg/(g*p*144);                             % Accelleration pressure drop(factor) from Bb
dPdZ_el = rhos*sind(inc);                               % Hydrostatic pressure drop, psi
dPdZ = (dPdZ_el + dPdZ_f)/(1-Ek)/144;                   % Total pressure drop, psi
vector = [vector rhos];

end
plot(vector)


    
