%clear all; close all; clc;
%hold all


%qL_SC = 2000;   %	Liquid production rate:	2000	  stb/d
%GLR = 1000;       %	Producing gas-liquid ratio (GLR):	1000	  scf/stb
%WC = 0.10;      %	Water cut (WC):	25	  %
%API = 20;       %	Oil gravity:	30	  oAPI
%yW = 1.05;      %	Water specific gravity:	1.05	  1 for fresh water
%yG = 0.66;      %	Gas specific gravity:	0.65	  1 for air
%T = 150;        %	Wellhead temperature:	100	  oF
%P = 200;
%do = 2.441/12;         %	Tubing ID:	1.66	  in 
%inc = 60;
%di = 0/12;


function extra = cor_input_MANY(do, inc, di, qL_SC, GLR, WC, API, yW, T, P, Mg, yG, T_pc, P_pc, e_rel, correlation)


%% Constants
rhoAIR = 0.0765;
g = 32.2;


%% Init Calc
dh = do - di;
ke = e_rel*dh;
Area = pi/4*(do^2-di^2);
yO = 141.5/(API+131.5);

qG_SC = qL_SC*GLR; %scf/day
qW_SC = qL_SC*WC; % bbl/day
qO_SC = qL_SC*(1-WC); %bbl/day
WOR = qW_SC/qO_SC;%bbl/stb
GOR = qG_SC/qO_SC; %scf/stb

Bw = bw_mccain(P,T);
pb = p_bubble(GOR,yG,T,API);                                         % Bubble Point Pressure, psi
[Rs, Bo] = standing(yG, API, pb, P, T); 
z = zfac4(T,P,T_pc,P_pc);                       % Gas Compressibility
Bg = (14.7/P)*((T+459.67)/519.67)*z;            % cuft/scf
qG = qO_SC/(24*3600)*(GOR-Rs)*Bg;               % cuft/sec
qO = 5.615/(24*3600)*qO_SC*Bo;                  % cuft/sec
qW = 5.615/(24*3600)*qW_SC*Bw;                  % cuft/sec
qL = qO + qW;                                   % cuft/sec
qT = qL + qG;                                   % cuft/sec
rhoG = rhoAIR*yG/Bg;                            % lbm/cuft
rhoO = (yO*62.4+yG*rhoAIR*Rs/5.615)/Bo;         % lbm/cuft
rhoW = yW*62.4/Bw;                              % lbm/cuft

VolumeO = Bo*5.615+Bg*Rs;                       % cuft/stb
VolumeW = Bw*5.615*WOR;                         % cuft/stb
VolumeL = VolumeO + VolumeW;                    % cuft/stb
VolumeG = Bg*(GOR-Rs);                          % cuft/stb
VolumeT = VolumeL + VolumeG;                    % cuft/stb

MassO = rhoO*qO;                                % lbm/sec
MassW = rhoW*qW;                                % lbm/sec
MassG = rhoG*qG;                                % lbm/sec
MassL = MassW + MassO;                          % lbm/sec
MassT = MassL + MassG;                          % lbm/sec


fO = qO/(qO+qW);                                % -
fW = 1 - fO;                                    % -
rhoL = rhoO*fO + rhoW*fW;                       % lbm/cuft
lamdaL = qL/(qL+qG);                            % -
lamdaG = 1 - lamdaL;                            % -
rhon = rhoL*lamdaL+rhoG*lamdaG;                 % Density, no-slip, lbm/cuft         % lbm/cuft
vsg = qG/Area;                                  % ft/sec
vsl = qL/Area;                                  % ft/sec
vm = vsg + vsl;                                 % ft/sec
Rv = vsl/vsg;

visO = oilviscosity(API,T,Rs,P,pb);             % cp
visW = waterviscosity(T);                       % cp
visG = gasviscosity(rhoG, Mg, T);               % cp
visL = visO*fO+visW*fW;                         % cp
visn = visL*lamdaL+visG*lamdaG;                 % cp
sigmaO = IFT(API,P,T);                          % dynes/cm2
sigmaW = IFTW(P,T);                             % dynes/cm2
sigmaL = sigmaO*fO+sigmaW*fW;                   % dynes/cm2

NLV = 1.938*vsl*(rhoL/sigmaL)^(1/4);
VAL_TRUE = real(rhon*vm*dh);
VAL_TEST = max(3.2, min(110,VAL_TRUE));

switch correlation
    case 'Hagedorn'
        V = num2cell(hagedorn_brown_parameters(rhoL, sigmaL, vsl, vsg, dh, visL, P));
        [~, ~, ~, ~, ~, ~, ~, HL] = V{:};
    case 'Dun'
        HL = dunrosHL(vsg, vsl, rhoL, sigmaL, visL, dh);
        if isnan(HL)
            HL = 0;
        end
    case 'Gray'
        [HL, ke] = gray_HL(rhon, vm, g, lamdaL, sigmaL, rhoL, rhoG, dh, Rv, ke);
    case 'BeggsBrill'
        NFR = vm^2/(g*dh);                               % Froude Number 
        HL = beggs_brill_cor(NFR, lamdaL, NLV, inc);
    otherwise
        HL = lamdaL;
end

if HL < 0.01;
    HL = 0.01;
end

HG = 1 - HL;                                    % -
vg = vsg/HG;                                    % ft/sec
vl = vsl/HL;                                    % ft/sec
vs = vg - vl;                                   % ft/sec
viss = visL^HL*visG^HG;                         % cp
rhok = rhoL*lamdaL^2/HL + rhoG*lamdaG^2/HG;     % lbm/cuft
rhos = rhoL*HL + rhoG*HG;                       % Density, slip, lbm/cuft
NRes = 1488*rhon*vm*dh/viss;                    % Reynolds number, hagedorn slipviscosity
NRen = 1488*rhon*vm*dh/visn;                    % Reynolds number, no-slip


switch correlation
    case 'Hagedorn'
        f = (1/(-1.8*log10(((ke/dh)/3.7)^1.11+(6.9/NRes))))^2; % Haaland
    case 'Gray'
        f = (1/(-1.8*log10(((ke/dh)/3.7)^1.11+(6.9/NRes))))^2; % Haaland
    case 'PoettmannSIMPLIFIED'
        f = 4*10^(1.444-2.5*log10(VAL_TEST));
    case 'Poettmann'
        load Poettmann.txt
        x_poettmann = Poettmann(:,1);
        y_poettmann = Poettmann(:,2);       
        f = interp1(x_poettmann,y_poettmann,VAL_TEST);
    case 'Baxendell'
        load Baxendell.txt
        x_baxendell = Baxendell(:,1);
        y_baxendell = Baxendell(:,2);
        f = interp1(x_baxendell,y_baxendell,VAL_TEST);
    case 'Brown'
        if GLR < 1500
            load BrownGLRb1500
            x_brown = BrownGLRb1500(:,1);
            y_brown = BrownGLRb1500(:,2);
        elseif GLR > 3000
            load BrownGLRa3000    
            x_brown = BrownGLRa3000(:,1);
            y_brown = BrownGLRa3000(:,2);
        else
            load BrownGLR1500t3000
            x_brown = BrownGLR1500t3000(:,1);
            y_brown = BrownGLR1500t3000(:,2);
        end
        f = interp1(x_brown,y_brown,VAL_TEST);
    case 'BeggsBrill'
        fn = 1/(2*log10(NRen/(4.5223*log10(NRen)-3.8215)))^2;   % Friction factor, no-slip
        y = lamdaL/HL^2;                                       % Adjustment parameter
        y1 = log(y);                                            % Adjustment parameter
        if ((1<y) && (y<1.2))
            S = log(2.2*y-1.2);                                 % Slip correction parameter
        else
            S = y1/(-0.0523+3.182*y1-0.8725*y1^2+0.01853*y1^4); % Slip correction parameter
        end
        es = exp(S);                                            % Slip correction
        ftp = es*fn;                                            % Friction factor, two-phase flow
        f = ftp;
end



switch correlation
    case 'BeggsBrill'
        dPdZ_f = f*rhon*vm^2/(2*g*dh);                  % Frictional pressure drop, lbf/cuft
    case 'Dun'
        [dPdZ_f, f] = dunrosfric(vsg, vsl, rhoL, rhoG, sigmaL, visL, visG, dh, e_rel);
    otherwise
        dPdZ_f = f*rhon^2*vm^2/(2*g*dh*rhos);           % Frictional pressure drop, lbf/cuft
end


Ek = rhos*vm*vsg/(g*P*144);                             % Accelleration pressure drop(factor) from Bb
dPdZ_el = rhos*sind(inc);                               % Hydrostatic pressure drop, psi
dPdZ = (dPdZ_el + dPdZ_f)/(1-Ek)/144;                   % Total pressure drop, psi

extra = [dPdZ dPdZ_el/144 dPdZ_f/144 vsl qG/qT];

end
