% 
% %%%% DUN AND ROSS METHOD FOR TWO PHASE FLOW IN VERTICAL PIPE %%%%
% %%%% EXAMPLE FROM PETROLEUM AND NATURAL GAS HANDBOOK P492-500 %%%
% 
% 
% %% Input Section
% 
% d = 1.995;      % tubing diameter, inch
% P1 = 1455;      % Well head pressure, psig
% dP = 500;       % Pressure differential, psi
% P2 = P1 + dP;   % Pressure at en of interval, psi
% pbar = 14.7;    % Atomspheric pressure, psi
% TavgR = 550;    % Average temperature, rankine
% TavgF = 90;     % Average temperature, farenheit
% SGg = 0.752;    % Specific gravity gas, sg
% SGw = 1.05;     % Specifig gravity water
% API = 54;       % Oil gravity, degrees API
% qO = 480;       % Oil flow rate, bpd (std)
% qW = 0;         % Water flow rate, bpd (std)
% qL = qO + qW;   % Liquid flow rate
% visG = 0.020;   % Gas viscosity, cp (assumed constant)
% sigmaO = 28;    % Interfacial tension oil, dynes/cm2
% GLR = 3393;     % Gas liquid ratio, GOR, scf/bbl
% WOR = qW/qO;    % Water oil Ratio, bbl/bbl
% 
% 
% %% Initial Calculations
% 
% SGo = 141.5/(131.5+API);
% m = SGo*350*(1/(1+WOR))+SGo*350*(WOR/(1+WOR))+0.0764*GLR*SGg;   % Mass of one bbl stock tank liquid
% yL = 62.4*(SGo*(1/(1+WOR))+SGw*(WOR/(1+WOR)));                  % Specific weight of liquid phase, lbm/cuft
% 
% Pavg = (P1+P2)/2 + pbar;        % Average Pressure;
% 
% Z = 0.72;                       %%%% GAS COMPRESSIBILITY FACTOR %%%%% ASSUMED
% 
% yG = SGg*0.0764*(Pavg/14.7)*(520/TavgR)/Z;                       % Specific weight of gas phase, lbm/cuft
% 
% 
% Rs = SGg*(Pavg/18*10^(0.0125*API)/10^(0.00091*TavgF))^1.2048;              % Solution Gas oil Ratio, scf/stb
% 
% 
% 
% %% Oil Viscosity Corrolation
% x = TavgF^-1.163*exp(6.9824-0.04658*API);
% visOd = 10^x -1;                            % Dead oil viscosity, cp
% 
% A = 10.715*(Rs+100)^-0.515;
% B = 5.44*(Rs+150)^-0.338;
% 
% visO = A*visOd^B;
% 
% %% Water Properties
% visW = 1;           % Water viscosity, cp %% ASSUMED CONSTANT %%
% sigmaW = 10;
% 
% %% Liquid mixture properties
% 
% visL = visO*(1/(1+WOR))+visW*(WOR/(1+WOR));
% sigmaL = sigmaO*(1/(1+WOR))+sigmaW*(WOR/(1+WOR));
% 
% 
% %% 
% 
% 
% yGm = SGg;
% yOm = SGo;
% 
% F = Rs*(yGm/yOm)^0.5 + 1.25*TavgF;
% Bo = 0.972+0.00147*F^1.175;                 %%% Sjekk denne, viktig
% 
% Bo = 1.495;     %bbl/stb
% 
% 
% Ap = pi*(d/12)^2/4;
% 
% 
% Bw = 1;
% vsl = 5.61*qL/86400/Ap*(Bo*(1/(1+WOR))+Bw*(WOR/(1+WOR)));
% vsg = qL*(GLR-Rs*(1/(1+WOR)))/86400/Ap*(14.7/Pavg)*(TavgR/520)*Z;
% 
% 
% %% Flow numbers
% 
% NL = 0.1573*visL*(1/(sigmaL^3*yL))^0.25;
% NLV = 1.938*vsl*(yL/sigmaL)^0.25;
% NGV = 1.938*vsg*(yL/sigmaL)^0.25;
% Nd = 120.9*(d/12)*(yL/sigmaL)^0.5;      % For annular flow use wetted perimeter d = dc+dt ???
% 
% 
% 
% %% Find flow region
% REGION = 2;
% 
% F1 = 1;
% F2 = 1;
% F3 = 1;
% F4 = 1;
% 
% F5 = 0.218;
% F6 = 0.58;
% F7 = 0.12;
% F6m = 0.029*Nd+0.58;
% 
% 
% %% Region 1
% % F3m = F3 - F4/Nd;
% % S1 = F1 + F2*NLV + F3m*(NGV/(1+NLV))^2;
% % vs = S1/(1.938*(yL/sigmaL)^0.5);
% % HL = (vs-vsg-vsl+((vs-vsg-vsl)^2+4*vs*vsl)^0.5)/(2*vs);
% % 
% 
% %% Region 2
% S2 = (1+F5)*((NGV^0.982+F6m))/(1+F7*NLV)^2;
% vs = S2/(1.938*(yL/sigmaL)^0.5);
% HL = (vs-vsg-vsl+((vs-vsg-vsl)^2+4*vs*vsl)^0.5)/(2*vs);
% 
% 
% % %% Region 3
% % S3 = 0;
% % HL = 1/(1+(vsg/vsl))
% % 
% 
% %%
% 
% NRe = 1488*yL*vsl*(d/12)/visL;
% 
% f1 = 0.005;
% f2 = 1.01;
% 
% % Gyldig i region 1 og 2
% R = vsg/vsl;
% f3 = 1 + f1*(R/50)^0.5;
% fw = f1*f2/f3;
% Gfr = 2*fw*NLV*(NLV+NGV)/Nd;
% 
% % Gyldig i region 3
% % e = 0.00015;
% % eod = e/(d/12);
% % f1 = 1/(4*log10(0.027*eod))^2+0.067*eod^1.73;
% % fw = f1;
% % Nrho = rhoG/rhoL;
% % Gfr = 2*fw*Nrho*NGV^2/Nd;
% 
% Gst = HL + (1-HL)*yG/yL;
% 
% % Region 1 og 2
% G = Gst + Gfr;
% 
% % Region 3
% %y = yG; %??
% %G = (Gst+Gfr)/(1-(yL*vsl+yG*vsg)*(vsg/y));        %  ????????????????
% 
% 
% dPdLst = Gst*yL/144;
% dPdLfr = Gfr*yL/144;
% dPdLtot = G*yL/144;
% 
% dL = dP/dPdLtot
% 


function [dPdZ_f, ff] = dunrosfric(vsg, vsl, rhoL, rhoG, sigmaL, visL, visG, dh, e_rel)

load dunros.mat
ff = 0;

NLV = real(1.938*vsl*(rhoL/sigmaL)^(1/4));
NGV = real(1.938*vsg*(rhoL/sigmaL)^(1/4));
Nd = real(120.872*dh*(rhoL/sigmaL)^(1/2));

Nd = max(20,min(Nd,300));

g = 32.2;
vm = vsl + vsg;
ke = e_rel*dh;

Ls = 50 + 36*NLV;
Lm = 75 + 84*NLV^0.75;
L1 = interp1(L1(:,1), L1(:,2), Nd);
L2 = interp1(L2(:,1), L2(:,2), Nd);
        
if (0 <= NGV && NGV <= L1 + L2*NLV)
    FLOW = 'Bubble Flow';
elseif (L1+L2*NLV <= NGV && NGV <= Ls)
    FLOW = 'Slug Flow';
elseif (NGV > Lm)
    FLOW = 'Mist Flow';
elseif (Ls < NGV && NGV < Lm)
    FLOW = 'Trans';
else % Assued Transient
    FLOW = 'Trans';
end


switch FLOW
    case 'Bubble Flow'
        NReL = real(1488*rhoL*vsl*dh/visL);
        f1 = real((1/(-1.8*log10(((ke/dh)/3.7)^1.11+(6.9/NReL))))^2); %Haaland
        f2 = interp1(f2(:,1), f2(:,2), real(f1*vsg*Nd^(2/3)/vsl));
        f3 = 1 + f1*sqrt(vsg/(50*vsl));
        fm = f1*f2/f3;
        ff = fm;
        dPdZ_f = fm*rhoL*vsl*vm/(2*g*dh);
        
    case 'Slug Flow'
        NReL = real(1488*rhoL*vsl*dh/visL);
        f1 = real((1/(-1.8*log10(((ke/dh)/3.7)^1.11+(6.9/NReL))))^2); %Haaland
        f2 = interp1(f2(:,1), f2(:,2), f1*vsg*Nd^(2/3)/vsl);
        f3 = 1 + f1*sqrt(vsg/(50*vsl));
        fm = f1*f2/f3;
        ff = fm;
        dPdZ_f = fm*rhoL*vsl*vm/(2*g*dh);
        
    case 'Mist Flow'
        NWe = real(rhoG*vsg^2*ke/sigmaL);
        Nmy = real(visL^2/(rhoL*sigmaL*ke));
        if NWe*Nmy <= 0.005
            ke = real(0.0749*sigmaL/(rhoG*vsg^2*dh)*dh);
        else
            ke = 0.3713*sigmaL/(rhoG*vsg^2*dh)*(NWe*Nmy)^0.302*dh;
        end
        NReG = real(rhoG*vsg*dh/visG);
        if ke/dh > 0.05
            f = 4*(1/(4*log10(0.27*ke/dh))^2 + 0.067*(ke/dh)^1.73);
        else
            f = (1/(-1.8*log10(((ke/dh)/3.7)^1.11+(6.9/NReG))))^2;
        end
        ff = f;
        dPdZ_f = f*rhoG*vsg^2/(2*g*dh);
               
        
    case 'Trans'
     
        NReL = 1488*rhoL*vsl*dh/visL;
        f1 = real((1/(-1.8*log10(((ke/dh)/3.7)^1.11+(6.9/NReL))))^2); %Haaland
        f2 = interp1(f2(:,1), f2(:,2), real(f1*vsg*Nd^(2/3)/vsl));
        f3 = 1 + f1*sqrt(vsg/(50*vsl));
        fm = f1*f2/f3;
        dPdZ_f_slug = fm*rhoL*vsl*vm/(2*g*dh);
        
        rhoGm = rhoG*NGV/Lm;
        NWe = rhoGm*vsg^2*ke/sigmaL;
        Nmy = visL^2/(rhoL*sigmaL*ke);
        if NWe*Nmy <= 0.005
            ke = 0.0749*sigmaL/(rhoGm*vsg^2*dh)*dh;
        else
            ke = 0.3713*sigmaL/(rhoGm*vsg^2*dh)*(NWe*Nmy)^0.302*dh;
        end
        NReG = rhoGm*vsg*dh/visG;
        if ke/dh > 0.05
            f = 4*(1/(4*log10(0.27*ke/dh))^2 + 0.067*(ke/dh)^1.73);
        else
            f = (1/(-1.8*log10(((ke/dh)/3.7)^1.11+(6.9/NReG))))^2;
        end
        dPdZ_f_mist = f*rhoGm*vsg^2/(2*g*dh);
        A = (Lm-NGV)/(Lm-Ls);
        B = 1-A;
        ff = A*fm+B*f;
        dPdZ_f = A*dPdZ_f_slug + B*dPdZ_f_mist;
                         
end

if isnan(dPdZ_f)
    dPdZ_f = 0;
end


end
