function[Qout, Pout, yin, yout, CleaningFactor,vf,Phyd,Pfric] = foamval(OD,ID,inc,Cs,Ds,SGc,yL,Sg,Qf,ROP,Pin,Ql_V,D,Tin,Tout,Qin,e_rel,YP,PV,visL,Correlation)

%% Well and Drill String Data
%OD = 7.875;
%ID = 4.5;
%inc = 0;
%Cs = 0.04; %CuttingsCons
%Ds = 0.5;     %CuttingsSize
%SGc = 2.7;
%yL = 62.4;
%Sg = 1;
%Qf = 0;    %bbl/hr
%ROP = 60;   %ft/hr
%rhos = SGc*62.4;
%Pin = 100;
%Ql_V = 50;
%D = 9500;
%Tin = 540;
%Tout = 635; 
%Qin = 0.95; % Maximum Gas Quality 
%e_rel = 0.0006;
%visL, lbm/ft-s
%

g = 32.2;
rhos = SGc*62.4;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Ql = max(Ql_V, eps);
Area = pi/4*(OD^2-ID^2);    % sqin
DH = (OD-ID)/12;            % ft
GLR = Qin/(1-Qin)*((1/7.48)+(5.615*Qf/(60*Ql)));  % scf/gal
yin = yL - (yL-2.7*Sg*Pin/Tin)*Qin;
yout = yin;


    
for sim = 1:2
    
    iteration = 0;
    dev = 1;
    Pout_Guess = 0;
        
    switch sim
        case 1
            static = 1;
            Pout = 0;
            Qout = 0;
        case 2
            static = 0;
    end
    
    while abs(dev) > 0.0001
        iteration = iteration + 1;
        yavg = mean([yin,yout]);
        Pavg = mean([Pin Pout]);
        Qavg = mean([Qin Qout]);
        if static == 1;
            f = 0;
            vf = 0;
        else
            vf = ((Pin*Tout/(Pavg*Tin)*GLR)+1/7.48+5.615*Qf/(60*Ql))/Area*(144/60*Ql);
            vis_e = foamrheology(Qavg,vf,OD/12,ID/12,YP,PV,visL,Correlation);
            NRe = vf*yavg*DH/vis_e;
            if NRe < 2000            
                f = 64/NRe;
            elseif NRe > 4000
                f = 0.184*(NRe)^-0.2;
            else
                f = (1/(-1.8*log10(((e_rel)/3.7)^1.11+(6.9/NRe))))^2; % Haaland
                %f = colbrookwhite(e_rel, NRe);
            end
        end
        
        dPdL_el = yavg*sind(inc)/144;       % psi/ft
        dPdL_f = yavg*f*vf^2/(2*g*DH)/144;  % psi/ft
        Phyd = dPdL_el*D;                   % psi
        Pfric = dPdL_f*D;                   % psi
        Ptot = Phyd + Pfric;                % psi
        Pout = Pin + Ptot;                  % psi        
        Qout = (Pin*Tout/(Pout*Tin)*GLR)/((Pin*Tout/(Pout*Tin)*GLR)+1/7.48+5.615*Qf/(60*Ql));
        yout = yL - (yL-2.7*Sg*Pout/Tout)*Qout;              % lb/cuft  
        dev = Pout_Guess - Pout;
        Pout_Guess = Pout;
        
        % Section Tries Average Value of Two Iterations if Convergence Fails
        if iteration == 201
            dev1 = dev;                                               % Holds Calculated Deviation
            val1 = Pout_Guess;                                        % Holds Calculated Pressure
        elseif iteration == 202
            dev2 = dev;                                               % Holds Calculated Deviation, psi
            val2 = Pout_Guess;                                        % Holds Calculated Pressure, psi
            Pout_Guess = mean([val1 val2]);                           % Average Pressure of Two Last Iterations, psi
            dev = mean([dev1 dev2]);                                  % Average Deviation of Two Last Iterations, psi
            if abs(dev) > 0.1
                interp1([dev1 dev2], [val1 val2],0);
                Pout_Guess = interp1([dev1 dev2], [val1 val2],0);
                dev = 0;
            end
        end
           
        
        
        
    end
end

vf = ((Pin*Tout/(Pout*Tin)*GLR)+1/7.48+5.615*Qf/(60*Ql))/Area*(144/60*Ql);
vis_e = foamrheology(Qavg,vf,OD/12,ID/12,YP,PV,visL,Correlation);
vsl = 1.56*Ds/12*(rhos-yout)^0.667/(yout^0.333*vis_e^0.333);
vtr = pi*OD^2/(4*Cs*Area)*(ROP/3600);
vreq = vsl + vtr;
CleaningFactor = vf/vreq;


end



