
function [Mg, yG, T_pc, P_pc] = gasprop(GAS)

    switch GAS 
        case {'AIR'}
            yG = 1;
        case {'NH3'}
            yG = 0.59;
        case {'CO2'}
            yG = 1.5189;
        case {'CH4'}
            yG = 0.5537;
        case {'N2'}
            yG = 0.9669;
        case {'O2'}
            yG = 1.1044;
        case {'C3H8'}
            yG = 1.5219;
        case {'SO2'}
            yG = 2.264;
        otherwise
            yG = str2double(inputdlg('Gas Specific Gravity, Air = 1'));
    end

    
% Section Below Assigns the Correct Pseudo-critical Properties for the
% Relevant Gastype (in Rankine and psi)

switch GAS 
    case {'AIR'}
        T_pc = 132.6*9/5;       % Pseudo-Critical Temperature Air, R
        P_pc = 37.71*14.5;      % Pseudo-Critical Pressure Air, psi
    case {'NH3'}
        T_pc = 405.5*9/5;       % Pseudo-Critical Temperature NH3, R
        P_pc = 112.8*14.5;      % Pseudo-Critical Pressure NH3, psi
    case {'CO2'}
        T_pc = 304.2*9/5;       % Pseudo-Critical Temperature CO2, R
        P_pc = 73.825*14.5;     % Pseudo-Critical Pressure CO2, psi
    case {'CH4'}
        T_pc = 190.5*9/5;       % Pseudo-Critical Temperature CH4, R
        P_pc = 45.96*14.5;      % Pseudo-Critical Pressure CH4, psi
    case {'N2'}
        T_pc = 126.2*9/5;       % Pseudo-Critical Temperature N2, R
        P_pc = 33.999*14.5;     % Pseudo-Critical Pressure N2, psi
    case {'O2'}
        T_pc = 154.5*9/5;       % Pseudo-Critical Temperature O2, R
        P_pc = 50.43*14.5;      % Pseudo-Critical Pressure O2, psi
    case {'C3H8'}
        T_pc = 369.8*9/5;       % Pseudo-Critical Temperature C3H8, R
        P_pc = 42.5*14.5;       % Pseudo-Critical Pressure C3H8, psi
    case {'SO2'}
        T_pc = 430.8*9/5;       % Pseudo-Critical Temperature SO2, R
        P_pc = 78.84*14.5;      % Pseudo-Critical Pressure SO2, psi
    otherwise
        [T_pc, P_pc] = sutton(yG);
end

Mg = 28.97*yG;

end