% Function calculates gas viscosity based on Lee-Gonzalez Model
% (presented on page 26 Whitson)

% Input, gas properties:
% rho   - Gas Density @ P,T, lbm/cuft
% Mg    - Molar Mass 
% T     - Temperature, Farenheit

% Output:
% visGas - gas viscosity, cp

function visGas = gasviscosity(rho, Mg, T)

T = T + 459.67;     % Converts Farenheit to Rankine
rho = rho/62.37;    % Converts lbm/cuft to g/cc

A = (9.379 + 0.01607*Mg)*T^(1.5)/(209.2 + 19.26*Mg + T);	 
B = 3.448 + 0.01009*Mg+ 986.4/T;
C = 2.447 - 0.2224*B;

visGas = A*10^(-4)*exp(B*rho^C);    % Calculated gas viscosity, cp        

end

