% Calculates Reservoir Inflow Based on Vogel's Equation and Constant GOR

% Input:
% Qmax - Maximum Flow Rate, bbl/day
% BHP - Estimated BHP, psi
% Presavg - Estimated Reservoir Pressure, psi
% GOR - Gas Oil Ration, scf/bbl

% Output:
% Qo - Oil Flow Rate, bbl/day
% Qg - Gas Flow Rate, scf/day


function [Qo, Qg] = inflow(Qmax, BHP, Presavg, GOR)
    if BHP < Presavg
        Qo = Qmax*(1-0.2*BHP/Presavg-0.8*(BHP/Presavg)^2);
        Qg = Qo*GOR;
    else
        Qo = 0;
        Qg = 0;
    end
end

