
clear all;
close all;
clc;

qL_SC = 2000;
GLR = 2000;
WC = 0.1;
API = 20;
yW = 1.05;
T = 150;
Pv = 1:2000;

hold all

for P = Pv

[Mg, yG, T_pc, P_pc] = gasprop('N2');
%% Constants
rhoAIR = 0.0765;
g = 32.2;


%% Init Calc
yO = 141.5/(API+131.5);

qG_SC = qL_SC*GLR; %scf/day
qW_SC = qL_SC*WC; % bbl/day
qO_SC = qL_SC*(1-WC); %bbl/day
WOR = qW_SC/qO_SC;%bbl/stb
GOR = qG_SC/qO_SC; %scf/stb

Bw = bw_mccain(P,T);
pb = p_bubble(GOR,yG,T,API);                                         % Bubble Point Pressure, psi
[Rs, Bo] = standing(yG, API, pb, P, T); 
z = zfac4(T,P,T_pc,P_pc);                       % Gas Compressibility
Bg = (14.7/P)*((T+459.67)/519.67)*z;            % cuft/scf
qG = qO_SC*(GOR-Rs)*Bg/(3600*24);               % cuft/sec
qO = 5.615/(24*3600)*qO_SC*Bo;                  % cuft/sec
qW = 5.615/(24*3600)*qW_SC*Bw;                  % cuft/sec
qL = qO + qW;                                   % cuft/sec
qT = qL + qG;                                   % cuft/sec
rhoG = rhoAIR*yG/Bg;                            % lbm/cuft
rhoO = (yO*62.4+yG*rhoAIR*Rs/5.615)/Bo;         % lbm/cuft
rhoW = yW*62.4/Bw;                              % lbm/cuft

VolumeO = Bo*5.615+Bg*Rs;                       % cuft/stb
VolumeW = Bw*5.615*WOR;                         % cuft/stb
VolumeL = VolumeO + VolumeW;                    % cuft/stb
VolumeG = Bg*(GOR-Rs);                          % cuft/stb
VolumeT = VolumeL + VolumeG;                    % cuft/stb

MassO = rhoO*qO;                                % lbm/sec
MassW = rhoW*qW;                                % lbm/sec
MassG = rhoG*qG;                                % lbm/sec
MassL = MassW + MassO;                          % lbm/sec
MassT = MassL + MassG;                          % lbm/sec

Mass1(P) = MassW;
Mass2(P) = MassG;
Mass3(P) = MassO;
Mass4(P) = MassT;
end

grid on

Y = [transpose(Mass1) , transpose(Mass2), transpose(Mass3)];
area(Y)
