
function PARAMETERS = outputpara(T,P,API,qL_SC,GLR,WC,yW,do,di,GASTYPE)

[Mg, yG] = gasprop(GASTYPE);
rhoAIR = 0.0765;        % lbm/cuft
yO = 141.5/(131.5+API); % sg
dh = do - di;           % ft
A = pi/4*(do^2-di^2);   % sqft      
qG_SC = qL_SC*GLR;      % scf/day
qW_SC = qL_SC*WC;       % bbl/day
qO_SC = qL_SC*(1-WC);   % bbl/day
WOR = qW_SC/qO_SC;      % bbl/stb
GOR = qG_SC/qO_SC;      % scf/stb

pb = p_bubble(GOR,yG,T,API);                    % psi
[Rs, Bo] = standing(yG, API, pb, P, T);         % scf/STB % bbl/STB
z = zfac4(GASTYPE,T,P);                         % -
Bg = (14.7/P)*((T+459.67)/519.67)*z;            % cuft/scf
Bw = bw_mccain(P,T);                            % bbl/STB
qG = qO_SC*(GOR-Rs)*Bg/(3600*24);               % cuft/sec
qO = 6.49*10^-5*qO_SC*Bo;                       % cuft/sec
qW = 6.49*10^-5*qW_SC*Bw;                       % cuft/sec
qL = qO + qW;                                   % cuft/sec
qT = qL + qG;                                   % cuft/sec
rhoG = 2.7*P*yG/(z*(T+459.67));                 % lbm/cuft
rhoO = (yO*62.4+yG*0.0764*Rs/5.614)/Bo;         % lbm/cuft
rhoW = yW*62.4/Bw;                              % lbm/cuft

VolumeO = Bo*5.615;                             % cuft/stb
VolumeW = Bw*5.615*WOR;                         % cuft/stb
VolumeL = VolumeO + VolumeW;                    % cuft/stb
VolumeG = Bg*(GOR-Rs);                          % cuft/stb
VolumeT = VolumeL + VolumeG;                    % cuft/stb
MassW = 350.17*yO;                              % lbm/stb
MassO = 350.17*yW*WOR;                          % lbm/stb
MassL = MassW + MassO;                          % lbm/stb
MassG = GOR*rhoAIR*yG;                          % lbm/stb
MassT = MassL + MassG;                          % lbm/stb
%rhon = MassT/VolumeM;                          % lbm/cuft

fO = qO/(qO+qW);                                % -
fW = 1 - fO;                                    % -
rhoL = rhoO*fO + rhoW*fW;                       % lbm/cuft

lamdaL = qL/(qL+qG);                            % -
lamdaG = 1 - lamdaL;                            % -

rhon = rhoL*lamdaL+rhoG*lamdaG;                 % lbm/cuft

vsg = qG/A;                                     % ft/sec
vsl = qL/A;                                     % ft/sec
vm = vsg + vsl;                                 % ft/sec

visO = oilviscosity(API,T,Rs,P,pb);             % cp
visW = waterviscosity(T);                       % cp
visG = gasviscosity(rhoG, Mg, T);               % cp
sigmaO = IFT(API,P,T);                          % dynes/cm2
sigmaW = IFT(10,P,T);                           % dynes/cm2, ASSUMED CORRECT AT API=10, MAKE CORROLATION

visL = visO*fO+visW*fW;                         % cp
visn = visL*lamdaL+visG*lamdaG;                 % cp

sigmaL = sigmaO*fO+sigmaW*fW;                   % dynes/cm2

VHB = hagedorn_brown_parameters(rhoL, sigmaL, vsl, vsg, dh, visL, P); %[NLV NGV Nd NL CNL HL_phi phi HL];
HL = VHB(8);
HG = 1 - HL;                                    % -
vg = vsg/HG;                                    % ft/sec
vl = vsl/HL;                                    % ft/sec
vs = vg - vl;                                   % ft/sec
rhos = rhoL*HL+rhoG*HG;                         % lbm/cuft
viss = visL^HL*visG^HG;                         % cp
rhok = rhoL*lamdaL^2/HL + rhoG*lamdaG^2/HG;     % lbm/cuft

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
vectorWell = [A do di dh];
vectorFluidProp = [API Mg Rs z pb];
vectorFVF = [Bo Bw Bg];
vectorsg = [yO yW yG];
vector_q_SC = [qO_SC qW_SC qL_SC qG_SC];
vector_q = [qO qW qL qG qT];
vector_rho = [rhoO rhoW rhoL rhoG rhon rhos rhok];
vectorVolume = [VolumeO VolumeW VolumeL VolumeG VolumeT];
vectorMass = [MassO MassW MassL MassG MassT];
vectorvis = [visO visW visL visG visn viss];
vectorv = [vsl vsg vm vg vl vs];
vectorsigma = [sigmaO sigmaW sigmaL];  
vectorfrac = [WOR GOR GLR WC lamdaL lamdaG fO fW HL HG];
%VHB = [NLV NGV Nd NL CNL HL_phi phi HL];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
PARAMETERS = [P T vectorWell vectorFluidProp vectorFVF vectorsg vector_q_SC...
    vector_q vector_rho vectorVolume vectorMass vectorvis vectorv ...
    vectorsigma vectorfrac];

end



