%% This Section Plots the Results

switch MODE
    case 1
        % Plot static simulation
        subplot(141)
        plot(ds_dHS*12, ds_MDavg, ds_doDS*12, ds_MDavg, ds_diDS*12, ds_MDavg)
        set(gca,'YDir','reverse')
        title('Diameter Deviated Well')
        xlabel('Diameter, in')
        ylabel('Measured Depth, ft')
        legend('ID Casing','OD Drill Pipe', 'ID Drill Pipe')
        grid on
        subplot(142)
        plot(ds_dPdZA, ds_MDavg, 'r', ds_dPdZD, ds_MDavg, 'b')
        set(gca,'YDir','reverse')
        title('Pressure Gradient Deviated Well')
        xlabel('Pressure, psi/ft')
        ylabel('Measured Depth, ft')
        legend('Annulus', 'Drill String')
        grid on
        subplot(143)
        plot(ds_pavgA, ds_MDavg, 'r', ds_pavgD, ds_MDavg, 'b')
        set(gca,'YDir','reverse')
        title('Pressure Profile Deviated Well')
        xlabel('Pressure, psi')
        ylabel('Measured Depth, ft')
        legend('Annulus', 'Drill String')
        grid on
        subplot(144)
        plot(Vsec, ds_TVDavg, 'r')
        set(gca,'YDir','reverse')
        title('Well Trajectory')
        xlabel('Vertical Section, ft')
        ylabel('True Vertical Depth, ft')
        xmin = min(Vsec)-100;
        xmax = max(Vsec)+100;
        xlim([xmin xmax])
        legend('Well')
        grid on
    case 2
        % Plot UBD Envelope
        hold all
        plot(qG_SCv/1000000, ptot, 'DisplayName', ['qL: ' ,num2str(qL_SC), ' stb/d'])
        xlabel('Gas Flow Rate, MMscf/d')
        ylabel('BHP, psi')
        title('UBD envelope')
        grid on
    case 3
        % Plot Pressure Contributions
        hold all
        plot(qG_SCv/1000000, dens, 'DisplayName', ['Hydrostatic Pressure for qL: ', num2str(qL_SC), ' stb/d'])
        plot(qG_SCv/1000000, fric, 'DisplayName', ['Frictional Pressure for qL: ' , num2str(qL_SC), ' stb/d'])
        plot(qG_SCv/1000000, ptot, 'DisplayName', ['Bottom Hole Pressure for qL: ', num2str(qL_SC), ' stb/d'])
        xlabel('Gas Flow Rate, MMscf/d')
        ylabel('Pressure, psi')
        title('Pressure Contributions')
        grid on
    case 4
        % Plot Gas Quality
        subplot(4,1,1:3)
        hold all
        plot(qG_SCv/1000000, QualGasS, 'DisplayName', ['Surface for qL: ' ,num2str(qL_SC), ' stb/d'])
        plot(qG_SCv/1000000, QualGas, 'DisplayName', ['Bottomhole for qL: ' ,num2str(qL_SC), ' stb/d'])
        axis([min(qG_SCv/1000000) max(qG_SCv/1000000) 0 1])
        title('Gas Qualities')
        xlabel('Gas Flow Rate, MMscf/d')
        ylabel('Gas Quality')
        grid on
        subplot(4,1,4)
        hold all
        plot(qG_SCv/1000000, GLRv, 'DisplayName', ['GLR for qL: ' ,num2str(qL_SC), ' stb/d'])
        ylabel('GLR, scf/stb')
        grid on
    case 5
        % Plot BHP vs Choke
        subplot(4,1,1:2)
        hold all
        plot(Psv, ptot, 'DisplayName', ['qL: ' ,num2str(qL_SC), ' stb/d'])
        title('Back-Pressure Envelope')
        xlabel('Back-Pressure, psi')
        ylabel('BHP, psi')
        grid on
        subplot(4,1,3:4)
        hold all
        plot(Psv, QualGasS, 'DisplayName', ['Surface for qL: ' ,num2str(qL_SC), ' stb/d'])
        ylabel('Gas Quality')
        xlabel('Back-Pressure, psi')
        grid on
end

drawnow