
if MODE == 1
    if min_annular_velocity < 120
        f = warndlg('Minimum annular velocity is below 120 ft/sec. Hole cleaning might be insufficient, consider increasing flow rate');
        waitfor(f)
    end
end


%% This Section Plots the Results

switch MODE
    case 1
        % Plot static simulation
        subplot(151)
        plot(ds_dHS*12, ds_MDavg, ds_doDS*12, ds_MDavg, ds_diDS*12, ds_MDavg)
        set(gca,'YDir','reverse')
        title('Diameter Well')
        xlabel('Diameter, in')
        ylabel('Measured Depth, ft')
        legend('ID Casing','OD Drill Pipe', 'ID Drill Pipe')
        grid on
        subplot(152)
        plot(ds_vmA, ds_MDavg, 'r', ds_vmD, ds_MDavg, 'b')
        set(gca,'YDir','reverse')
        title('Velocities')
        xlabel('Mixture Velocity, ft/sec')
        ylabel('Measured Depth, ft')
        legend('Annulus','Drill String')
        grid on
        subplot(153)
        plot(ds_dPdZA, ds_MDavg, 'r', ds_dPdZD, ds_MDavg, 'b')
        set(gca,'YDir','reverse')
        title('Pressure Gradient')
        xlabel('Pressure, psi/ft')
        ylabel('Measured Depth, ft')
        legend('Annulus', 'Drill String')
        grid on
        subplot(154)
        plot(ds_pavgA, ds_MDavg, 'r', ds_pavgD, ds_MDavg, 'b')
        set(gca,'YDir','reverse')
        title('Pressure Profile')
        xlabel('Pressure, psi')
        ylabel('Measured Depth, ft')
        legend('Annulus', 'Drill String')
        grid on
        subplot(155)
        plot(Vsec, ds_TVDavg, 'r')
        set(gca,'YDir','reverse')
        title('Well Trajectory')
        xlabel('Vertical Section, ft')
        ylabel('True Vertical Depth, ft')
        xmin = min(Vsec)-100;
        xmax = max(Vsec)+100;
        xlim([xmin xmax])
        legend('Well')
        grid on
    case 2
        % Plot UBD Envelope
        hold all
        min_annular_velocity = real(min_annular_velocity);
        min_annular_velocity(isnan(min_annular_velocity)) = 0 ;
        min_vel_point = interp1(min_annular_velocity,1:length(min_annular_velocity),120);
        mvy = interp1(1:length(ptot),ptot,min_vel_point);
        mvx = interp1(1:length(qG_SCv/1000000),qG_SCv/1000000,min_vel_point);
        plot(qG_SCv/1000000, ptot, 'DisplayName', ['qL: ' ,num2str(qL_SC), ' stb/d'])
        plot(mvx,mvy,'o', 'DisplayName', ['Cleaning Limit for qL: ' ,num2str(qL_SC), ' stb/d'])
        xlabel('Gas Flow Rate, MMscf/d')
        ylabel('BHP, psi')
        title('UBD envelope')
        grid on
    case 3
        % Plot Pressure Contributions
        hold all
        plot(qG_SCv/1000000, dens, 'DisplayName', ['Hydrostatic Pressure for qL: ', num2str(qL_SC), ' stb/d'])
        plot(qG_SCv/1000000, fric, 'DisplayName', ['Frictional Pressure for qL: ' , num2str(qL_SC), ' stb/d'])
        plot(qG_SCv/1000000, ptot, 'DisplayName', ['Bottom Hole Pressure for qL: ', num2str(qL_SC), ' stb/d'])
        xlabel('Gas Flow Rate, MMscf/d')
        ylabel('Pressure, psi')
        title('Pressure Contributions')
        grid on
    case 4
        % Plot Gas Quality
        subplot(4,1,1:3)
        hold all
        plot(qG_SCv/1000000, QualGasS, 'DisplayName', ['Surface for qL: ' ,num2str(qL_SC), ' stb/d'])
        plot(qG_SCv/1000000, QualGas, 'DisplayName', ['Bottomhole for qL: ' ,num2str(qL_SC), ' stb/d'])
        axis([min(qG_SCv/1000000) max(qG_SCv/1000000) 0 1])
        title('Gas Qualities')
        xlabel('Gas Flow Rate, MMscf/d')
        ylabel('Gas Quality')
        grid on
        subplot(4,1,4)
        hold all
        plot(qG_SCv/1000000, GLRv, 'DisplayName', ['GLR for qL: ' ,num2str(qL_SC), ' stb/d'])
        ylabel('GLR, scf/stb')
        grid on
    case 5
        % Plot BHP vs Choke
        subplot(2,1,1)
        hold all
        plot(Psv, ptot, 'DisplayName', ['qL: ' ,num2str(qL_SC), ' stb/d'])
        title('Back-Pressure Envelope')
        xlabel('Back-Pressure, psi')
        ylabel('BHP, psi')
        grid on
        subplot(2,1,2)
        hold all
        plot(Psv, QualGasS, 'DisplayName', ['Surface for qL: ' ,num2str(qL_SC), ' stb/d'])
        ylabel('Gas Quality')
        xlabel('Back-Pressure, psi')
        grid on
end



drawnow


