% Function calculates pressure drop over the drill bit
% Simplified Model (fluid acts as one-phase flow)

% Input:
% Q     -   Flow Rate, gpm
% rho   -   Mixture Density, lbm/cuft
% Cd    -   Discharge Coefficient [0.8 1.03, API = 0.98]
% N     -   Nozzle Size (1/32 in)

% Output:
% dPbit -   Pressure Drop, psi

function dPbit = pnozzle(Q, rho, Cd, NV)

    At = sum(NV.^2);
    %At = N1^2 + N2^2 + N3^2;            % Flow Area Jets 
    dPbit = 156*rho*Q^2/(Cd^2*At^2);    % Pressure Drop, psi
end
