
GEOds = get(handles.schematicds,'Data');
GEOcsg = get(handles.schematiccsg,'Data');

OHd = str2double(get(handles.edit99,'String'));
BitDepth = str2double(get(handles.edit100,'String'));
axes(handles.schematicplot)

cla
casingcolor = [1, 0, 0];
drillstringcolor = [0, 0, 1];
OHcolor = [0, 1, 1];
Rescolor = [0, 1, 0];

TDSA = sum(GEOds(:,4)); % Total Drill String Available, ft
if BitDepth>TDSA
    errordlg('Drill String Too Short to Reach Simulation Depth');
end

axis([-20 20 -10 TDSA])
DEPTH = 0;

%% Reservoir Information
TOPOFRES = str2double(get(handles.edit101,'String'));
ResHeight = str2double(get(handles.edit103,'String'));
pr = str2double(get(handles.edit104,'String'));
TVDresAVG = TOPOFRES + ResHeight/2;
TempTable = get(handles.temptable, 'Data');
T = interp1(TempTable(:,1),TempTable(:,3),TVDresAVG);        % Temperature at btm of interval, Farenheit
GOR = str2double(get(handles.edit107,'String'));
API = str2double(get(handles.edit105,'String'));
WC = str2double(get(handles.edit106,'String'));
xx = get(handles.popupmenu14, 'String');
yy = get(handles.popupmenu14, 'Value');
GASTYPE = char(xx(yy));
[Mg, yG, T_pc, P_pc] = gasprop(GASTYPE);
Bw = bw_mccain(pr,T);
pb = p_bubble(GOR,yG,T,API);
[Rs, Bo] = standing(yG, API, pb, pr, T);
fO = (1-WC)*Bo/((1-WC)*Bo+WC*Bw);
fW = 1 - fO;
B = fO*Bo+Bw*Bw;
visO = oilviscosity(API,T,Rs,pr,pb);             % cp
visW = waterviscosity(T);                       % cp
vis = visO*fO+visW*fW;                          % cp
            

%%
axes(handles.schematicplot)
rectangle('Position',[-20,TOPOFRES,40,ResHeight],'FaceColor', Rescolor)


casingstrings = size(GEOcsg,1);

for n = 1:casingstrings
    x = -GEOcsg(n,1)/2;
    y = GEOcsg(n,3);
    w = GEOcsg(n,1)/2-GEOcsg(n,2)/2;
    h = GEOcsg(n,4)-GEOcsg(n,3);
    rectangle('Position',[x,y,w,h],'FaceColor', casingcolor)
    x = GEOcsg(n,1)/2-w;
    rectangle('Position',[x,y,w,h],'FaceColor', casingcolor)
    if y+h < BitDepth
        DEPTH = [DEPTH y y+h];
    else
        DEPTH = [DEPTH BitDepth];
    end
end

drillstrings = size(GEOds,1);


%% Plot OH Section
OHl = BitDepth-GEOcsg(casingstrings,4);
if OHl > 0
    x = OHd/2;
    y = GEOcsg(casingstrings,4);
    w = 0.1;
    h = OHl;
    rectangle('Position',[x,y,w,h],'FaceColor', OHcolor)
    x = -OHd/2-w;
    rectangle('Position',[x,y,w,h],'FaceColor', OHcolor)
end

%%

LASTDEPTH = BitDepth;

for n = drillstrings:-1:1
    
    if (TDSA > 0 && LASTDEPTH > 0)
        
    PIPELENGTH = GEOds(n,4);
    TOPOFSECTION = max(LASTDEPTH-PIPELENGTH,0);
    BOTTOMOFSECTION = LASTDEPTH;
    SECTIONLENGTH = BOTTOMOFSECTION-TOPOFSECTION; 
    
    x = -GEOds(n,1)/2;
    y = TOPOFSECTION;
    w = GEOds(n,1)/2-GEOds(n,2)/2;
    h = SECTIONLENGTH;
    rectangle('Position',[x,y,w,h],'FaceColor', drillstringcolor)
    x = GEOds(n,1)/2-w;
    rectangle('Position',[x,y,w,h],'FaceColor', drillstringcolor)
    DEPTH = [DEPTH y h+y];
    
    LASTDEPTH = LASTDEPTH - SECTIONLENGTH;
    end
    TDSA = TDSA - SECTIONLENGTH;
    
    HVds(n,:) = [GEOds(n,1) GEOds(n,2) TOPOFSECTION BOTTOMOFSECTION];
end


temp = unique(DEPTH);

i = 1;
v = zeros(length(temp),4);


for a = temp
    
    if a > 0
        a = a - 0.001;
    end
    
    nd = [];
    nc = [];
    d1 = [];
    d2 = [];
    d3 = [];
    
for n = 1:drillstrings
    if ((HVds(n,3)<= a) && (a <= HVds(n,4)))
        nd = [nd n];
        d1 = [d1 HVds(n,2)];
        d2 = [d2 HVds(n,1)];
    end
end

for n = 1:casingstrings
    if ((GEOcsg(n,3)<= a) && (a <= GEOcsg(n,4)))
        nc = [nc n];
        d3 = [d3 GEOcsg(n,2)];
    end
end
 
v(i,1) = a;
v(i,2) = min(d1);
v(i,3) = max(d2);
if isempty(d3)
    v(i,4) = OHd;
else
    v(i,4) = min(d3);
end

i = i + 1;
end

if BitDepth > TOPOFRES  
    
    PayZone = min(ResHeight, BitDepth-TOPOFRES);   
    
    choice = questdlg(['Reservoir intersected, ' num2str(PayZone) ' ft. Choose Reservoir Inflow:'], ...
	'IPR', ...
	'Known Reservoir Properties','Known Maximum Flowrate','No Inflow', 'No Inflow');
    
    switch choice
        case 'Known Maximum Flowrate'
            qLs = inputdlg('Maximum Flowrate stb/day:','Input',1,{'3000'});
            qLmaxInflow = str2double(cell2mat(qLs));
            IPRdata = qLmaxInflow;
        case 'Known Reservoir Properties'
            prompt = {'Permeability, mD:','Effective Drainage Radius, ft:','Skin Factor:'};
            dlg_title = 'Input';
            num_lines = 1;
            def = {'8.2','2000','0'};
            answer = inputdlg(prompt,dlg_title,num_lines,def);
            [k, re, S] = answer{:};
            k = str2double(k);
            re = str2double(re);
            S = str2double(S);
            pwf = 0;
            qLmaxInflow = vogeladvanced(k,PayZone,pr,pwf,pb,re,OHd/2,S,B,vis);
            IPRdata = [k; re; S];
        case 'No Inflow'
            qLmaxInflow = 0;
            IPRdata = 0;
    end
    msgbox(['Max Flow Rate Estimated to ' num2str(qLmaxInflow) ' stb/d'])
else
    IPRdata = 0;
end


set(handles.uitable18, 'Data',IPRdata)
set(handles.schematictot,'Data',v);

set(gca,'Ydir', 'reverse')
grid on