%% Mixture Properties

qG_SC = qL_SC*GLR; %scf/day
qW_SC = qL_SC*WC; % bbl/day
qO_SC = qL_SC*(1-WC); %bbl/day

APIin = str2double(get(handles.edit105,'String'));
yWin = str2double(get(handles.edit114,'String'));

if exist('yGin')
    % Do nothing
else
    x = get(handles.popupmenu14, 'String');
    y = get(handles.popupmenu14, 'Value');
    GASTYPEin = char(x(y));
    [~, yGin, T_pcin, P_pcin] = gasprop(GASTYPEin);
end


yO = 141.5/(API+131.5);
yOin = 141.5/(APIin+131.5);

qL_SCmix = qL_SC + qLin_SC;
qG_SCmix = qG_SC + qGin_SC;
qO_SCmix = qO_SC + qOin_SC;
qW_SCmix = qW_SC + qWin_SC;

yGmix = (qG_SC*yG + qGin_SC*yGin)/qG_SCmix;
yOmix = (qO_SC*yO + qOin_SC*yOin)/qO_SCmix;
yWmix = (qW_SC*yW + qWin_SC*yWin)/qW_SCmix;

if isnan(yGmix)
    yGmix = yG;
end
if isnan(yOmix)
    yOmix = yO;
end
if isnan(yWmix)
    yWmix = yW;
end

GLRmix = qG_SCmix/qL_SCmix;
WCmix = qW_SCmix/qL_SCmix;
APImix = 141.5/yOmix - 131.5;

if (yGin == yG)
    [Mgmix, ~, T_pcmix, P_pcmix] = gasprop(GASTYPE);
else
    Mgmix = 28.97*yGmix;
    [T_pcmix, P_pcmix] = sutton(yGmix);
end

if MODE == 1
   wbarmax = 2*intervals;
   wbarc = 0;
end

%% Section Simulates Fluid Flow Up Annulus
% Simulated against flow direction  - Positive pressure gradient
        
for ii = 1:intervals                                                      % Loop over all intervals  
    if MODE == 1;
        wbarc = wbarc + 1;
        waitbar(wbarc/wbarmax,h)
    end
    deviation = 1000;                                                       % Define Pressure deviation, psi
    ds_iterA(ii) = 0;                                                       % Initiate Interval Iteration Counter
    while(abs(deviation)>limit)                                           % Checks if iteration limit is reached
        
        ds_iterA(ii) = ds_iterA(ii) + 1;                                    % Iteration Counter Increases
        
        % Section Estimates the Average Pressure
        if (ii>1)
            ds_pinA(ii) = ds_poutA(ii-1);                                   % Inlet Pressure Equals Outles Pressure Last Interval
        else
            ds_pinA(ii) = P_Choke;                                          % Inlet Pressure Equals Choke Pressure at Surface
        end
        
        if ds_dp_guessA(ii) < 0;
            ds_dp_guessA(ii) = abs(ds_dp_guessA(ii));
        end
        ds_poutA(ii) = ds_pinA(ii) + ds_dp_guessA(ii);                      % Calculates Outlet Pressure from Inlet and Guessed Change, psi
        ds_pavgA(ii) = (ds_pinA(ii) + ds_poutA(ii))/2;                      % Average Pressure, psi      
        
        do = ds_dHS(ii);
        inc = ds_phiA(ii);
        di = ds_doDS(ii);
        T = ds_TavgF(ii);
        P = ds_pavgA(ii);
        
        ds_vmA(ii,:) = mixturevelocity(do, di, qL_SC, GLR, WC, API, T, P, yG, T_pc, P_pc);
        
        vectorout(ii,:) = cor_input_MANY(do, inc, di, qL_SCmix, GLRmix, WCmix, APImix, yWmix, T, P, Mgmix, yGmix, T_pcmix, P_pcmix, e_rel, correlation);
        ds_dPdZA(ii) = vectorout(ii,1); %(cor_input(do, inc, di, qL_SC, GLR, WC, API, yW, yG, T, P);
        ds_dPdP_FF(ii) = vectorout(ii,3).*ds_dZ(ii);                              % Calculated Pressure Change Over Interval, psi
        ds_dPdP_MW(ii) = vectorout(ii,2).*ds_dZ(ii);              % Calculated Pressure Change Over Interval, psi

                
        ds_dPA(ii) = ds_dPdZA(ii).*ds_dZ(ii);                               % Calculated Pressure Change Over Interval, psi
        deviation = ds_dp_guessA(ii)-ds_dPA(ii);                            % Pressure Deviation From Guess, psi 
        ds_dp_guessA(ii) = ds_dPA(ii);                                      % New Guess Pressure Change (next iteration), psi
        
        % Section Tries Average Value of Two Iterations if Convergence Fails
        if (ds_iterA(ii) == 201)
            dev1 = real(deviation);                                               % Holds Calculated Deviation
            val1 = real(ds_dp_guessA(ii));                                        % Holds Calculated Pressure
        elseif (ds_iterA(ii) == 202)
            dev2 = real(deviation);                                               % Holds Calculated Deviation, psi
            val2 = real(ds_dp_guessA(ii));                                        % Holds Calculated Pressure, psi
            ds_dp_guessA(ii) = mean([val1 val2]);                           % Average Pressure of Two Last Iterations, psi
            deviation = mean([dev1 dev2]);                                  % Average Deviation of Two Last Iterations, psi
            if abs(deviation) > 0.1
                interp1([dev1 dev2], [val1 val2],0);
                ds_dp_guessA(ii) = interp1([dev1 dev2], [val1 val2],0);
                deviation = 0;
            end
        end
           
    end
    ds_poutA(ii) = ds_pinA(ii) + ds_dPA(ii);                                % Outlet Pressure of Interval, psi

end

BHP = ds_poutA(intervals)     ;                                             % Estimated BHP (Outlet Pressure Last Interval), psi
%%%%%%%%%%%%%%%%
[qGin_SC, qWin_SC, qOin_SC, yGin, APIin, yWin] = inflowGUI(handles,BHP);
qLin_SC = qWin_SC + qWin_SC;
%%%%%%%%%%%%%%%

inflowdev = real(qL_SCmix-(qLin_SC+qL_SC));
if inflowdevcounter == 25
    dev1 = inflowdev;
    val1 = real(qLin_SC);
elseif inflowdevcounter == 26
    dev2 = inflowdev;
    val2 = real(qLin_SC);
    qLin_SC = interp1([dev1 dev2], [val1 val2],0);
    inflowdev = 0;
end
    


if (abs(inflowdev) < 0.01)
    balanced = 1;
end

if inflowdevcounter == 1;
    maxhh = abs(inflowdev);
end
    
if balanced
    if inflowdevcounter > 1
        waitbar(1,hh)
        close(hh)
    end          
    fric = [fric sum(ds_dPdP_FF)];
    dens = [dens sum(ds_dPdP_MW)];
    ptot = [ptot BHP];
    QualGas = [QualGas vectorout(intervals,5)];
    QualGasS = [QualGasS vectorout(1,5)];
else
    if inflowdevcounter > 1
        hval = 1-(log(inflowdev)-log(0.01))/(log(maxhh)-log(0.01));
        waitbar(hval,hh)
    end
end





