%% Bit Pressure Drop
BitVal = get(handles.uitable17, 'Data');
if length(BitVal) == 1;
    dPbit = BitVal;
else
    Cd = BitVal(1);
    NV = BitVal(2:11);
    % Section Calculate Fluid Properties At Bit
    [qT, rhoM] = helpfunction_bit(qL_SC,...
    GLR, WC, API, yW, T_pc, P_pc, yG, TA(intervals), BHP);
    q_bit = qT*60*12^3/231;                                                     % Converts Flow from cuft/sec to gpm
    rho_bit = rhoM/(12^3/231);                                                  % Converts Mixture Density from lbm/cuft to ppg
    dPbit = pnozzle(q_bit,rho_bit,Cd,NV);             % Pressure Drop Over Bit, psi
end
ds_pinD(intervals) = BHP + dPbit;      


%% Section Simulates Fluid Flow Down Drill String
% Simulated against flow direction  - Positive pressure gradient
for ii = intervals:-1:1                                                     % Loop over all intervals
   
    wbarc = wbarc + 1;
    waitbar(wbarc/wbarmax)
    
    deviation = 1000;                                                       % Define Pressure deviation, psi
    ds_iterD(ii) = 0;
    
    while(abs(deviation)>limit)                                             % Checks if iteration limit is reached

        ds_iterD(ii) = ds_iterD(ii) + 1;                                    % Iteration Counter Increases

        % Section Estimates the Average Pressure
        if (ii ~= intervals)
            ds_pinD(ii) = ds_poutD(ii+1);                                   % Inlet Pressure Equals Outles Pressure Last Interval
        else
            ds_pinD(ii) = BHP + dPbit;                                       % Inlet Pressure Equals Choke Pressure at Surface
        end      
        ds_poutD(ii) = ds_pinD(ii) + ds_dp_guessD(ii);                      % Calculates Outlet Pressure from Inlet and Guessed Change, psi
        ds_pavgD(ii) = (ds_pinD(ii) + ds_poutD(ii))/2;                      % Average Pressure, psi
        
        do = ds_diDS(ii);
        inc = ds_phiD(ii);
        di = 0;
        T = ds_TavgF(ii);
        P = ds_pavgD(ii);
        
        vectorout(ii,:) = cor_input_MANY(do, inc, di, qL_SC, GLR, WC, API, yW, T, P, Mg, yG, T_pc, P_pc, e_rel, correlation);
        ds_dPdZD(ii) = vectorout(ii,1); %(cor_input(do, inc, di, qL_SC, GLR, WC, API, yW, yG, T, P);
        ds_dPdP_FF(ii) = vectorout(ii,3).*ds_dZ(ii);                              % Calculated Pressure Change Over Interval, psi
        ds_dPdP_MW(ii) = vectorout(ii,2).*ds_dZ(ii);              % Calculated Pressure Change Over Interval, psi
        
        ds_dPD(ii) = ds_dPdZD(ii).*ds_dZ(ii);                               % Calculated Pressure Change Over Interval, psi
        deviation = ds_dp_guessD(ii)-ds_dPD(ii);                            % Pressure Deviation From Guess, psi
        ds_dp_guessD(ii) = ds_dPD(ii);                                      % New Guess Pressure Change (next iteration), psi
          
        % Section Tries Average Value of Two Iterations if Convergence Fails
        if (ds_iterD(ii) == 201)
            dev1 = deviation;                                               % Holds Calculated Deviation
            val1 = ds_dp_guessD(ii);                                        % Holds Calculated Pressure
        elseif (ds_iterD(ii) == 202)
            dev2 = deviation;                                               % Holds Calculated Deviation, psi
            val2 = ds_dp_guessD(ii);                                        % Holds Calculated Pressure, psi
            ds_dp_guessD(ii) = mean([val1 val2]);                           % Average Pressure of Two Last Iterations, psi
            deviation = mean([dev1 dev2]);                                  % Average Deviation of Two Last Iterations, psi
        end
        
    end
    
    ds_poutD(ii) = ds_pinD(ii) + ds_dPD(ii);                                % Outlet Pressure of Interval, psi
    
end
PDS = ds_poutD(1);                                                          % Estimated Drill Pipe Pressure (Outlet Pressure Last Interval), psi
