

if get(handles.radiobutton7, 'Value') == 1
    CHOKEMODE = 'Manuel';
elseif get(handles.radiobutton8, 'Value') == 1
    CHOKEMODE = 'Auto';
    AUTOMODE = 'BHP';
    BHPW = str2double(get(handles.edit120,'String'));
elseif get(handles.radiobutton9, 'Value') == 1
    CHOKEMODE = 'Auto';
    AUTOMODE = 'CHOKE';   
    PCW = str2double(get(handles.edit121,'String'));
end



%% Mixture Properties
qG_SC = qL_SC*GLR; %scf/day
qW_SC = qL_SC*WC; % bbl/day
qO_SC = qL_SC*(1-WC); %bbl/day

APIin = str2double(get(handles.edit105,'String'));
yWin = str2double(get(handles.edit114,'String'));

if exist('yGin')
    % Do nothing
else
    x = get(handles.popupmenu14, 'String');
    y = get(handles.popupmenu14, 'Value');
    GASTYPEin = char(x(y));
    [~, yGin, T_pcin, P_pcin] = gasprop(GASTYPEin);
    save yGinTEMP.mat yGin
end

yO = 141.5/(API+131.5);
yOin = 141.5/(APIin+131.5);

qL_SCmix = qL_SC + qLin_SC;
qG_SCmix = qG_SC + qGin_SC;
qO_SCmix = qO_SC + qOin_SC;
qW_SCmix = qW_SC + qWin_SC;

yGmix = (qG_SC*yG + qGin_SC*yGin)/qG_SCmix;
yOmix = (qO_SC*yO + qOin_SC*yOin)/qO_SCmix;
yWmix = (qW_SC*yW + qWin_SC*yWin)/qW_SCmix;

if isnan(yGmix)
    yGmix = yG;
end
if isnan(yOmix)
    yOmix = yO;
end
if isnan(yWmix)
    yWmix = yW;
end

GLRmix = qG_SCmix/qL_SCmix;
WCmix = qW_SCmix/qL_SCmix;
APImix = 141.5/yOmix - 131.5;
Mgmix = 28.97*yGmix;
[T_pcmix, P_pcmix] = sutton(yGmix);

% Saves all fluid properties for influx in this current timestep
fname = ['StaticValues' num2str(t)];
save(fname, 'qL_SCmix', 'GLRmix', 'WCmix', 'APImix', 'yWmix', 'Mgmix', 'yGmix', 'T_pcmix', 'P_pcmix')

% Find Choke Pressure Drop for Current Fluid
% Choke data
Choke_max = 4;                                      % Maximum Choke Opening, in
CN_GUI = get(handles.slider5, 'Value');             % Choke Percentage Opening
d = CN_GUI/100*64*Choke_max;                        % Initial Choke Opening, 1/64 inch
%dCH = []; % [64.59*ones(1,250)];                    % Choke Openings, 1/64 inch

% switch CHOKEMODE
%     case 'Auto'
%         if t>1
%            d = dCH(t-1);
%         end
% end

% Find ShiftRate in this current timestep and adjustinflowmatrix
preparegrid
dt = 60;
if t>1
    P = BHPdyn(t-1);
    T = TA(intervals); 
    WellAnnularVolume = sum(transpose(ds_Aann).*ds_dZ);
    [rhoInflux, influxRate] = fluidprop(qL_SC, GLR, WC, API, yW, T, P, yG, T_pc, P_pc); % cuft/sec & lbm/cuft
    AverageIntervalAnnularVolume = WellAnnularVolume/intervals; % Volume  Interval, cuft
    MassCapacityAtBottom = AverageIntervalAnnularVolume*rhoInflux; % lbm
    MassInflux = influxRate*dt*rhoInflux; %cuft/sec*s/min*lbm/cuft = lbm/min
    ShiftRate = MassInflux/MassCapacityAtBottom;           % Number of Intervals Influx Fills 1/min
    ShiftRate = round(ShiftRate);
    if isnan(ShiftRate)
        ShiftRate = 1;
    end
else
    ShiftRate = 1;
end
if ShiftRate < 2
    ShiftRate = 2;
end
if t>1
AdjustedInflowMatrix(:,t) = AdjustedInflowMatrix(:,t-1);
end
AdjustedInflowMatrix(:,t) = shift(AdjustedInflowMatrix(:,t),ShiftRate);
AdjustedInflowMatrix((intervals-ShiftRate+1):intervals,t) = t*ones(ShiftRate,1);

devB = 100;


switch CHOKEMODE
    case 'Auto'
        if t>1
           d = dCH(t-1);
        end
end


while (abs(devB)>1)

%% Section Simulates Fluid Flow Up Annulus
% Simulated against flow direction  - Positive pressure gradient
        
for ii = 1:intervals                                                      % Loop over all intervals  
    if MODE == 1;
        wbarc = wbarc + 1;
        waitbar(wbarc/wbarmax,h)
    end
    deviation = 1000;                                                       % Define Pressure deviation, psi
    ds_iterA(ii) = 0; % Initiate Interval Iteration Counter
    
    % Load relevant fluid properties for this interval
    t_adjusted = AdjustedInflowMatrix(ii,t); 
    fname = ['StaticValues' num2str(t_adjusted)];
    load(fname);
        
    if ii == 1
        P_Choke = choke(qL_SCmix, GLRmix, d);             % Initial Back Pressure, psi
    end
    
    while(abs(deviation)>limit)                                           % Checks if iteration limit is reached
        
        ds_iterA(ii) = ds_iterA(ii) + 1;                                    % Iteration Counter Increases
        
        % Section Estimates the Average Pressure
        if (ii>1)
            ds_pinA(ii) = ds_poutA(ii-1);                                   % Inlet Pressure Equals Outles Pressure Last Interval
        else
            ds_pinA(ii) = P_Choke;                                          % Inlet Pressure Equals Choke Pressure at Surface
        end
        ds_poutA(ii) = ds_pinA(ii) + ds_dp_guessA(ii);                      % Calculates Outlet Pressure from Inlet and Guessed Change, psi
        ds_pavgA(ii) = (ds_pinA(ii) + ds_poutA(ii))/2;                      % Average Pressure, psi      
        
        do = ds_dHS(ii);
        inc = ds_phiA(ii);
        di = ds_doDS(ii);
        T = ds_TavgF(ii);
        P = ds_pavgA(ii);
        
        
        vectorout(ii,:) = cor_input_MANY(do, inc, di, qL_SCmix, GLRmix, WCmix, APImix, yWmix, T, P, Mgmix, yGmix, T_pcmix, P_pcmix, e_rel, correlation);
        ds_dPdZA(ii) = vectorout(ii,1); %(cor_input(do, inc, di, qL_SC, GLR, WC, API, yW, yG, T, P);
        ds_dPdP_FF(ii) = vectorout(ii,3).*ds_dZ(ii);                              % Calculated Pressure Change Over Interval, psi
        ds_dPdP_MW(ii) = vectorout(ii,2).*ds_dZ(ii);              % Calculated Pressure Change Over Interval, psi
        GASFRAC(ii,t) = vectorout(ii,5);
                
        ds_dPA(ii) = ds_dPdZA(ii).*ds_dZ(ii);                               % Calculated Pressure Change Over Interval, psi
        deviation = ds_dp_guessA(ii)-ds_dPA(ii);                            % Pressure Deviation From Guess, psi 
        ds_dp_guessA(ii) = ds_dPA(ii);                                      % New Guess Pressure Change (next iteration), psi
        
        % Section Tries Average Value of Two Iterations if Convergence Fails
        if (ds_iterA(ii) == 201)
            dev1 = deviation;                                               % Holds Calculated Deviation
            val1 = ds_dp_guessA(ii);                                        % Holds Calculated Pressure
        elseif (ds_iterA(ii) == 202)
            dev2 = deviation;                                               % Holds Calculated Deviation, psi
            val2 = ds_dp_guessA(ii);                                        % Holds Calculated Pressure, psi
            ds_dp_guessA(ii) = mean([val1 val2]);                           % Average Pressure of Two Last Iterations, psi
            deviation = mean([dev1 dev2]);                                  % Average Deviation of Two Last Iterations, psi
        end
           
    end
    ds_poutA(ii) = ds_pinA(ii) + ds_dPA(ii);                                % Outlet Pressure of Interval, psi

end

BHP = ds_poutA(intervals)     ;                                             % Estimated BHP (Outlet Pressure Last Interval), psi
%%%%%%%%%%%%%%%%
[qGin_SC, qWin_SC, qOin_SC, yGin, APIin, yWin] = inflowGUI(handles,BHP);
qLin_SC = qWin_SC + qWin_SC;
%%%%%%%%%%%%%%%

inflowdev = qL_SCmix-(qLin_SC+qL_SC);

if (abs(inflowdev) < 0.01)
    balancedinflow = 1;
else
    balancedinflow = 0;
end

if inflowdevcounter == 1;
    maxhh = abs(inflowdev);
end
    
switch CHOKEMODE
    case 'Manuel'
        devB = 0;
    case 'Auto'
               
    switch AUTOMODE
        case 'BHP'
            t_adjusted = AdjustedInflowMatrix(1,t); 
            fname = ['StaticValues' num2str(t_adjusted)];
            load(fname);
            devB = BHPW-BHP;
            dd = choke_inv(qL_SCmix, GLRmix,P_Choke+devB);
            d = d + 0.5*(dd-d);  
        case 'CHOKE'
            t_adjusted = AdjustedInflowMatrix(1,t); 
            fname = ['StaticValues' num2str(t_adjusted)];
            load(fname);
            devB = PCW-P_Choke;
            d = choke_inv(qL_SCmix, GLRmix,PCW);

            
    end
    set(handles.slider5, 'Value', 100*d/Choke_max/64);             % Choke Percentage Opening
        
end

end

balancedchoke = 1;
if (balancedinflow && balancedchoke)
    balanced = 1;
end

if balanced

    switch MODE
        case 1
            close(hh)
        otherwise
            % Do nothing
            close(hh)
    end
    set(handles.edit120,'String',num2str(BHP))
    set(handles.edit121,'String',num2str(P_Choke))
    Influx = [Influx qLin_SC];
    dCH = [dCH d];
    PChokev = [PChokev P_Choke];
    fric = [fric sum(ds_dPdP_FF)];
    dens = [dens sum(ds_dPdP_MW)];
    ptot = [ptot BHP];
    QualGas = [QualGas vectorout(intervals,5)];
    QualGasS = [QualGasS vectorout(1,5)];
else
    switch MODE
        case 1
            waitbar(0,h)
            hval = 1-(log(inflowdev)-log(0.01))/(log(maxhh)-log(0.01));
            waitbar(hval,hh)
        otherwise
            % Do nothing
            hval = 1-(log(inflowdev)-log(0.01))/(log(maxhh)-log(0.01));
            waitbar(hval,hh)
    end
end




