% Function calcultes GOR & FVF at given conditions
% using Standings Corrolation

% Input:
% T - Temperature , Farenheit
% p - Pressure, psia
% yG - Specific Gravity Gas
% API - API Gravity Oil

% Output:
% Rs - Solution GOR, scf/STB
% Bo - Oil Formation Volume Factor, bbl/STB

function [Rs, Bo] = standing(yG, API, pb, p, T)

    yg = 0.00091*T - 0.0125*API;        % Fluid parameter
    Rs = yG * (p/18/10^yg)^1.204;       % GOR, scf/stb

    yO = 141.5/(API+131.5);             % Oil Specific Gravity
    F = Rs*(yG/yO)^0.5 + 1.25*T;        % Fluid parameter
    Bo = 0.972 + 0.000147*F^1.175;      % Formation Volume Factor, bbl/STB
      
    if p>pb
        Rs = yG * (pb/18/10^yg)^1.204;
        co = (-27321+33.784*Rs+238.81*T)/(10^6*p);  %Elsharkawy
        %co = 10*10^-6;
        F = Rs*(yG/yO)^0.5 + 1.25*T;
        Bob = 0.972 + 0.000147*F^1.175;
        Bo = Bob*exp(co*(pb-p));
    end
    
end
