
% p = 150;        % Pressure at calculation point, psi
% rhoL = 56.8;    % Liquid density at standard conditions, lbm/cuft
% w = 9.3;        % Total mass flow rate, lbm/sec
% API = 24;
% yG = 0.7;
% d = 2.992;
% z = 5985;       % Distance from Reference, ft
% TG = 1.06/100;  % Geothermat Gradient, F/ft
% phi = 90;       % Inclination from Horizontal;
% Tref = 170;     % Reference Temperature;

function dT = tempshiubeggs(TG,L,phi,d,p,API,yW,yG,qO_SC,qW_SC,qG_SC)

C0 = 0.0063;
C1 = 0.4882;
C2 = 2.9150;
C3 = -0.3476;
C4 = 0.2219;
C5 = 0.2519;
C6 = 4.7240;

yO = 141.5/(API+131.5);

w = 1/86400*(350*(qO_SC*yO+qW_SC*yW)+0.0764*qG_SC*yG);
rhoL = 62.4/(qO_SC+qW_SC)*(qO_SC*yO+qW_SC*yW);

A = C0*w^C1*rhoL^C2*d^C3*p^C4*API^C5*yG^C6;
dT = TG*L*sin(phi)+A*TG*sin(phi)*(1-exp(-L/A));

end
