% Function Calculates the Gas Compressibility Factor
% for a Given Temperature, Gastype and Pressure Using the DAK-EOS

% Input:
% GAS       -   Gastype
% T         -   Temperature, Farenheit
% P         -   Pressure, psi

% Output:
% Z_calc    -   Gas/Liquid/Total Flow Rate, cuft/sec

function Z_calc = zfac4(T,P,T_pc,P_pc)
% 
% % Section Below Assigns the Correct Pseudo-critical Properties for the
% % Relevant Gastype (in Rankine and psi)
% 
% switch GAS 
%     case {'AIR'}
%         T_pc = 132.6*9/5;       % Pseudo-Critical Temperature Air, R
%         P_pc = 37.71*14.5;      % Pseudo-Critical Pressure Air, psi
%     case {'NH3'}
%         T_pc = 405.5*9/5;       % Pseudo-Critical Temperature NH3, R
%         P_pc = 112.8*14.5;      % Pseudo-Critical Pressure NH3, psi
%     case {'CO2'}
%         T_pc = 304.2*9/5;       % Pseudo-Critical Temperature CO2, R
%         P_pc = 73.825*14.5;     % Pseudo-Critical Pressure CO2, psi
%     case {'CH4'}
%         T_pc = 190.5*9/5;       % Pseudo-Critical Temperature CH4, R
%         P_pc = 45.96*14.5;      % Pseudo-Critical Pressure CH4, psi
%     case {'N2'}
%         T_pc = 126.2*9/5;       % Pseudo-Critical Temperature N2, R
%         P_pc = 33.999*14.5;     % Pseudo-Critical Pressure N2, psi
%     case {'O2'}
%         T_pc = 154.5*9/5;       % Pseudo-Critical Temperature O2, R
%         P_pc = 50.43*14.5;      % Pseudo-Critical Pressure O2, psi
%     case {'C3H8'}
%         T_pc = 369.8*9/5;       % Pseudo-Critical Temperature C3H8, R
%         P_pc = 42.5*14.5;       % Pseudo-Critical Pressure C3H8, psi
%     case {'SO2'}
%         T_pc = 430.8*9/5;       % Pseudo-Critical Temperature SO2, R
%         P_pc = 78.84*14.5;      % Pseudo-Critical Pressure SO2, psi
% end

% Section Below Calculates the Pseudo-Reduced Properties and Calls the
% DAK-EOS Algorithm to Find the Correct Compressibility Factor, Z

P_pr = P / P_pc;                % Pseudo-Reduced Pressure
T_pr = (T+459.67)/ T_pc;        % Pseudo-Reduced Temperature
Z_calc = zfac5(T_pr,P_pr);      % Compressibility Factor @(Tpr, Ppr)
    
end


